// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/browser/performance_monitor/events.json
// DO NOT EDIT.

#ifndef CHROME_BROWSER_PERFORMANCE_MONITOR_EVENTS_H__
#define CHROME_BROWSER_PERFORMANCE_MONITOR_EVENTS_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace performance_monitor {

namespace events {
struct UncleanShutdown;
struct ExtensionUninstall;
struct RendererFreeze;
struct ChromeUpdate;
struct ExtensionUnload;
struct RendererCrash;
struct ExtensionInstall;
struct ExtensionEnable;
struct ExtensionUpdate;
}  // events

namespace events {

//
// Types
//

// The event to represent an unclean shutdown.
struct UncleanShutdown {
  ~UncleanShutdown();
  UncleanShutdown();

  // The type of the event.
  int event_type;

  // The time at which the event was recorded.
  double time;

  // Populates a UncleanShutdown object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, UncleanShutdown* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // UncleanShutdown object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(UncleanShutdown);
};

// The event to describe the uninstallation of an extension in Chrome.
struct ExtensionUninstall {
  ~ExtensionUninstall();
  ExtensionUninstall();

  // The extension's id.
  std::string extension_id;

  // The string reprepresentation of the extension's version.
  std::string extension_version;

  // The type of the event.
  int event_type;

  // The extension's install location.
  int extension_location;

  // The extension's url.
  std::string extension_url;

  // The extension's description.
  std::string extension_description;

  // The time at which the event was recorded.
  double time;

  // The extension's name.
  std::string extension_name;

  // Populates a ExtensionUninstall object from a Value. Returns whether |out|
  // was successfully populated.
  static bool Populate(const Value& value, ExtensionUninstall* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ExtensionUninstall object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ExtensionUninstall);
};

// The event to represent a frozen renderer (when the frozen tab popup comes
// up).
struct RendererFreeze {
  ~RendererFreeze();
  RendererFreeze();

  // The crash url.
  std::string url;

  // The type of the event.
  int event_type;

  // The time at which the event was recorded.
  double time;

  // Populates a RendererFreeze object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, RendererFreeze* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // RendererFreeze object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(RendererFreeze);
};

// The event to describe an update to Chrome; this will be recognized on
// startup by a change in the version number.
struct ChromeUpdate {
  ~ChromeUpdate();
  ChromeUpdate();

  // The type of the event.
  int event_type;

  // The string representation of the previous Chrome version.
  std::string previous_version;

  // The string representation of the current Chrome version.
  std::string current_version;

  // The time at which the event was recorded.
  double time;

  // Populates a ChromeUpdate object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, ChromeUpdate* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ChromeUpdate object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ChromeUpdate);
};

// The event to describe the unloading of an extension in Chrome.
struct ExtensionUnload {
  ~ExtensionUnload();
  ExtensionUnload();

  // The type of unload performed.
  int unload_reason;

  // The extension's id.
  std::string extension_id;

  // The string reprepresentation of the extension's version.
  std::string extension_version;

  // The type of the event.
  int event_type;

  // The extension's install location.
  int extension_location;

  // The extension's url.
  std::string extension_url;

  // The extension's description.
  std::string extension_description;

  // The time at which the event was recorded.
  double time;

  // The extension's name.
  std::string extension_name;

  // Populates a ExtensionUnload object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, ExtensionUnload* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ExtensionUnload object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ExtensionUnload);
};

// The event to represent a renderer crash.
struct RendererCrash {
  ~RendererCrash();
  RendererCrash();

  // The crash url.
  std::string url;

  // The type of the event.
  int event_type;

  // The time at which the event was recorded.
  double time;

  // Populates a RendererCrash object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, RendererCrash* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // RendererCrash object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(RendererCrash);
};

// The event to describe the installation of an extension in Chrome.
struct ExtensionInstall {
  ~ExtensionInstall();
  ExtensionInstall();

  // The extension's id.
  std::string extension_id;

  // The string reprepresentation of the extension's version.
  std::string extension_version;

  // The type of the event.
  int event_type;

  // The extension's install location.
  int extension_location;

  // The extension's url.
  std::string extension_url;

  // The extension's description.
  std::string extension_description;

  // The time at which the event was recorded.
  double time;

  // The extension's name.
  std::string extension_name;

  // Populates a ExtensionInstall object from a Value. Returns whether |out|
  // was successfully populated.
  static bool Populate(const Value& value, ExtensionInstall* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ExtensionInstall object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ExtensionInstall);
};

// The event to describe the uninstallation of an extension in Chrome.
struct ExtensionEnable {
  ~ExtensionEnable();
  ExtensionEnable();

  // The extension's id.
  std::string extension_id;

  // The string reprepresentation of the extension's version.
  std::string extension_version;

  // The type of the event.
  int event_type;

  // The extension's install location.
  int extension_location;

  // The extension's url.
  std::string extension_url;

  // The extension's description.
  std::string extension_description;

  // The time at which the event was recorded.
  double time;

  // The extension's name.
  std::string extension_name;

  // Populates a ExtensionEnable object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, ExtensionEnable* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ExtensionEnable object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ExtensionEnable);
};

// The event to describe the uninstallation of an extension in Chrome.
struct ExtensionUpdate {
  ~ExtensionUpdate();
  ExtensionUpdate();

  // The extension's id.
  std::string extension_id;

  // The string reprepresentation of the extension's version.
  std::string extension_version;

  // The type of the event.
  int event_type;

  // The extension's install location.
  int extension_location;

  // The extension's url.
  std::string extension_url;

  // The extension's description.
  std::string extension_description;

  // The time at which the event was recorded.
  double time;

  // The extension's name.
  std::string extension_name;

  // Populates a ExtensionUpdate object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, ExtensionUpdate* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ExtensionUpdate object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ExtensionUpdate);
};

}  // events
}  // performance_monitor

#endif  // CHROME_BROWSER_PERFORMANCE_MONITOR_EVENTS_H__
