// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/alarms.idl
// DO NOT EDIT.

#include "tools/json_schema_compiler/util.h"
#include "chrome/common/extensions/api/alarms.h"

using base::Value;
using base::DictionaryValue;
using base::ListValue;
using base::BinaryValue;
using json_schema_compiler::any::Any;

namespace extensions {
namespace api {
namespace alarms {

//
// Types
//

AlarmCreateInfo::AlarmCreateInfo()
   {}
AlarmCreateInfo::~AlarmCreateInfo() {}

// static
bool AlarmCreateInfo::Populate(const Value& value, AlarmCreateInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* delay_in_minutes_value = NULL;
  if (dict->GetWithoutPathExpansion("delayInMinutes", &delay_in_minutes_value)) {
    {
      double temp;
      if (!delay_in_minutes_value->GetAsDouble(&temp))
        return false;
      out->delay_in_minutes.reset(new double(temp));
    }
  }

  Value* period_in_minutes_value = NULL;
  if (dict->GetWithoutPathExpansion("periodInMinutes", &period_in_minutes_value)) {
    {
      double temp;
      if (!period_in_minutes_value->GetAsDouble(&temp))
        return false;
      out->period_in_minutes.reset(new double(temp));
    }
  }

  Value* when_value = NULL;
  if (dict->GetWithoutPathExpansion("when", &when_value)) {
    {
      double temp;
      if (!when_value->GetAsDouble(&temp))
        return false;
      out->when.reset(new double(temp));
    }
  }

  return true;
}

scoped_ptr<DictionaryValue> AlarmCreateInfo::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  if (delay_in_minutes.get())
    value->SetWithoutPathExpansion("delayInMinutes", Value::CreateDoubleValue(*this->delay_in_minutes));

  if (period_in_minutes.get())
    value->SetWithoutPathExpansion("periodInMinutes", Value::CreateDoubleValue(*this->period_in_minutes));

  if (when.get())
    value->SetWithoutPathExpansion("when", Value::CreateDoubleValue(*this->when));


  return value.Pass();
}


Alarm::Alarm()
  : scheduled_time(0.0) {}
Alarm::~Alarm() {}

// static
bool Alarm::Populate(const Value& value, Alarm* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* period_in_minutes_value = NULL;
  if (dict->GetWithoutPathExpansion("periodInMinutes", &period_in_minutes_value)) {
    {
      double temp;
      if (!period_in_minutes_value->GetAsDouble(&temp))
        return false;
      out->period_in_minutes.reset(new double(temp));
    }
  }

  Value* scheduled_time_value = NULL;
  if (!dict->GetWithoutPathExpansion("scheduledTime", &scheduled_time_value))
    return false;
  {
    if (!scheduled_time_value->GetAsDouble(&out->scheduled_time))
      return false;
  }

  Value* name_value = NULL;
  if (!dict->GetWithoutPathExpansion("name", &name_value))
    return false;
  {
    if (!name_value->GetAsString(&out->name))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> Alarm::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  if (period_in_minutes.get())
    value->SetWithoutPathExpansion("periodInMinutes", Value::CreateDoubleValue(*this->period_in_minutes));

  value->SetWithoutPathExpansion("scheduledTime", Value::CreateDoubleValue(this->scheduled_time));
  value->SetWithoutPathExpansion("name", Value::CreateStringValue(this->name));

  return value.Pass();
}


//
// Functions
//

Create::Params::Params() {}
Create::Params::~Params() {}

// static
scoped_ptr<Create::Params> Create::Params::Create(const ListValue& args) {
  if (args.GetSize() < 1 || args.GetSize() > 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* name_value = NULL;
  if (args.Get(0, &name_value) && !name_value->IsType(Value::TYPE_NULL))
  {
    {
      std::string temp;
      if (!name_value->GetAsString(&temp))
        return scoped_ptr<Params>();
      params->name.reset(new std::string(temp));
    }
  }

  Value* alarm_info_value = NULL;
  if (args.Get(1, &alarm_info_value) && !alarm_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!alarm_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!AlarmCreateInfo::Populate(*dictionary, &params->alarm_info))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}



Value* GetAll::Result::Create(const std::vector<linked_ptr<Alarm> >& alarms) {
  return json_schema_compiler::util::CreateValueFromArray(alarms).release();
}


Clear::Params::Params() {}
Clear::Params::~Params() {}

// static
scoped_ptr<Clear::Params> Clear::Params::Create(const ListValue& args) {
  if (args.GetSize() > 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* name_value = NULL;
  if (args.Get(0, &name_value) && !name_value->IsType(Value::TYPE_NULL))
  {
    {
      std::string temp;
      if (!name_value->GetAsString(&temp))
        return scoped_ptr<Params>();
      params->name.reset(new std::string(temp));
    }
  }

  return params.Pass();
}



Get::Params::Params() {}
Get::Params::~Params() {}

// static
scoped_ptr<Get::Params> Get::Params::Create(const ListValue& args) {
  if (args.GetSize() > 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* name_value = NULL;
  if (args.Get(0, &name_value) && !name_value->IsType(Value::TYPE_NULL))
  {
    {
      std::string temp;
      if (!name_value->GetAsString(&temp))
        return scoped_ptr<Params>();
      params->name.reset(new std::string(temp));
    }
  }

  return params.Pass();
}


Value* Get::Result::Create(const Alarm& alarm) {
  return alarm.ToValue().release();
}

}  // alarms
}  // api
}  // extensions
