// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/alarms.idl
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_ALARMS_H__
#define CHROME_COMMON_EXTENSIONS_API_ALARMS_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace alarms {
struct AlarmCreateInfo;
struct Alarm;
}  // alarms

namespace alarms {

//
// Types
//

struct AlarmCreateInfo {
  ~AlarmCreateInfo();
  AlarmCreateInfo();

  // Length of time in minutes after which the <code>onAlarm</code> event should
  // fire. <!-- TODO: need minimum=0 -->
  scoped_ptr<double> delay_in_minutes;

  // If set, the onAlarm event should fire every <var>periodInMinutes</var>
  // minutes after the initial event specified by <var>when</var> or
  // <var>delayInMinutes</var>.  If not set, the alarm will only fire once. <!--
  // TODO: need minimum=0 -->
  scoped_ptr<double> period_in_minutes;

  // Time at which the alarm should fire, in milliseconds past the epoch (e.g.
  // <code>Date.now() + n</code>).
  scoped_ptr<double> when;

  // Populates a AlarmCreateInfo object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, AlarmCreateInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // AlarmCreateInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(AlarmCreateInfo);
};

struct Alarm {
  ~Alarm();
  Alarm();

  // If not null, the alarm is a repeating alarm and will fire again in
  // <var>periodInMinutes</var> minutes.
  scoped_ptr<double> period_in_minutes;

  // Time at which this alarm was scheduled to fire, in milliseconds past the
  // epoch (e.g. <code>Date.now() + n</code>).  For performance reasons, the
  // alarm may have been delayed an arbitrary amount beyond this.
  double scheduled_time;

  // Name of this alarm.
  std::string name;

  // Populates a Alarm object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, Alarm* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // Alarm object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(Alarm);
};

//
// Functions
//

namespace Create {
  struct Params {
    // Optional name to identify this alarm. Defaults to the empty string.
    scoped_ptr<std::string> name;

    // Describes when the alarm should fire.  The initial time must be specified by
    // either <var>when</var> or <var>delayInMinutes</var> (but not both).  If
    // <var>periodInMinutes</var> is set, the alarm will repeat every
    // <var>periodInMinutes</var> minutes after the initial event.  If neither
    // <var>when</var> or <var>delayInMinutes</var> is set for a repeating alarm,
    // <var>periodInMinutes</var> is used as the default for
    // <var>delayInMinutes</var>.
    AlarmCreateInfo alarm_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

};

namespace GetAll {

  namespace Result {

    Value* Create(const std::vector<linked_ptr<Alarm> >& alarms);
  };

};

namespace ClearAll {

};

namespace Clear {
  struct Params {
    // The name of the alarm to clear. Defaults to the empty string.
    scoped_ptr<std::string> name;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

};

namespace Get {
  struct Params {
    // The name of the alarm to get. Defaults to the empty string.
    scoped_ptr<std::string> name;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const Alarm& alarm);
  };

};

}  // alarms
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_ALARMS_H__
