// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/content_settings.json
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_CONTENT_SETTINGS_H__
#define CHROME_COMMON_EXTENSIONS_API_CONTENT_SETTINGS_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace content_settings {
struct ResourceIdentifier;
}  // content_settings

namespace content_settings {

//
// Properties
//

//
// Types
//

// The only content type using resource identifiers is <a
// href="contentSettings.html#property-plugins"><var>plugins</var></a>. For
// more information, see <a
// href="contentSettings.html#resource-identifiers">Resource Identifiers</a>.
struct ResourceIdentifier {
  ~ResourceIdentifier();
  ResourceIdentifier();

  // The resource identifier for the given content type.
  std::string id;

  // A human readable description of the resource.
  scoped_ptr<std::string> description;

  // Populates a ResourceIdentifier object from a Value. Returns whether |out|
  // was successfully populated.
  static bool Populate(const Value& value, ResourceIdentifier* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ResourceIdentifier object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ResourceIdentifier);
};

namespace ContentSetting {
  namespace Clear {
    struct Params {
      struct Details {
        ~Details();
        Details();

        enum Scope {
          SCOPE_NONE,
          SCOPE_REGULAR,
          SCOPE_INCOGNITO_SESSION_ONLY,
        };

        static scoped_ptr<Value> CreateEnumValue(Scope scope);
        // Where to set the setting (default: regular). One of<br><var>regular</var>:
        // setting for regular profile (which is inherited by the incognito profile if
        // not overridden elsewhere),<br><var>incognito_session_only</var>: setting for
        // incognito profile that can only be set during an incognito session and is
        // deleted when the incognito session ends (overrides regular settings).
        Scope scope;

        // Populates a Details object from a Value. Returns whether |out| was
        // successfully populated.
        static bool Populate(const Value& value, Details* out);


       private:
        DISALLOW_COPY_AND_ASSIGN(Details);
      };

      Details details;

      ~Params();

      static scoped_ptr<Params> Create(const ListValue& args);

     private:
      Params();

      DISALLOW_COPY_AND_ASSIGN(Params);
    };

    namespace Result {
      Value* Create();
    };

  };

  namespace Set {
    struct Params {
      struct Details {
        ~Details();
        Details();

        enum Scope {
          SCOPE_NONE,
          SCOPE_REGULAR,
          SCOPE_INCOGNITO_SESSION_ONLY,
        };

        static scoped_ptr<Value> CreateEnumValue(Scope scope);
        // The resource identifier for the content type.
        scoped_ptr<ResourceIdentifier> resource_identifier;

        // The setting applied by this rule. See the description of the individual
        // ContentSetting objects for the possible values.
        json_schema_compiler::any::Any setting;

        // The pattern for the secondary URL. Defaults to matching all URLs. For
        // details on the format of a pattern, see <a
        // href='contentSettings.html#patterns'>Content Setting Patterns</a>.
        scoped_ptr<std::string> secondary_pattern;

        // Where to clear the setting (default: regular). One of<br><var>regular</var>:
        // setting for regular profile (which is inherited by the incognito profile if
        // not overridden elsewhere),<br><var>incognito_session_only</var>: setting for
        // incognito profile that can only be set during an incognito session and is
        // deleted when the incognito session ends (overrides regular settings).
        Scope scope;

        // The pattern for the primary URL. For details on the format of a pattern, see
        // <a href='contentSettings.html#patterns'>Content Setting Patterns</a>.
        std::string primary_pattern;

        // Populates a Details object from a Value. Returns whether |out| was
        // successfully populated.
        static bool Populate(const Value& value, Details* out);


       private:
        DISALLOW_COPY_AND_ASSIGN(Details);
      };

      Details details;

      ~Params();

      static scoped_ptr<Params> Create(const ListValue& args);

     private:
      Params();

      DISALLOW_COPY_AND_ASSIGN(Params);
    };

    namespace Result {
      Value* Create();
    };

  };

  namespace GetResourceIdentifiers {

    namespace Result {

      // A list of resource identifiers for this content type, or
      // <var>undefined</var> if this content type does not use resource
      // identifiers.
      Value* Create(const std::vector<linked_ptr<ResourceIdentifier> >& resource_identifiers);
    };

  };

  namespace Get {
    struct Params {
      struct Details {
        ~Details();
        Details();

        // The secondary URL for which the content setting should be retrieved.
        // Defaults to the primary URL. Note that the meaning of a secondary URL
        // depends on the content type, and not all content types use secondary URLs.
        scoped_ptr<std::string> secondary_url;

        // A more specific identifier of the type of content for which the settings
        // should be retrieved.
        scoped_ptr<ResourceIdentifier> resource_identifier;

        // The primary URL for which the content setting should be retrieved. Note that
        // the meaning of a primary URL depends on the content type.
        std::string primary_url;

        // Whether to check the content settings for an incognito session. (default
        // false)
        scoped_ptr<bool> incognito;

        // Populates a Details object from a Value. Returns whether |out| was
        // successfully populated.
        static bool Populate(const Value& value, Details* out);


       private:
        DISALLOW_COPY_AND_ASSIGN(Details);
      };

      Details details;

      ~Params();

      static scoped_ptr<Params> Create(const ListValue& args);

     private:
      Params();

      DISALLOW_COPY_AND_ASSIGN(Params);
    };

    namespace Result {
      struct Details {
        ~Details();
        Details();

        // The content setting. See the description of the individual ContentSetting
        // objects for the possible values.
        json_schema_compiler::any::Any setting;

        // Returns a new DictionaryValue representing the serialized form of this
        // Details object. Passes ownership to caller.
        scoped_ptr<DictionaryValue> ToValue() const;

       private:
        DISALLOW_COPY_AND_ASSIGN(Details);
      };

      Value* Create(const Details& details);
    };

  };

}

}  // content_settings
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_CONTENT_SETTINGS_H__
