// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/events.json
// DO NOT EDIT.

#include "tools/json_schema_compiler/util.h"
#include "chrome/common/extensions/api/events.h"

using base::Value;
using base::DictionaryValue;
using base::ListValue;
using base::BinaryValue;
using json_schema_compiler::any::Any;

namespace extensions {
namespace api {
namespace events {

//
// Types
//

Event::GetRules::Params::Params() {}
Event::GetRules::Params::~Params() {}

// static
scoped_ptr<Event::GetRules::Params> Event::GetRules::Params::Create(const ListValue& args) {
  if (args.GetSize() < 1 || args.GetSize() > 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* event_name_value = NULL;
  if (args.Get(0, &event_name_value) && !event_name_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!event_name_value->GetAsString(&params->event_name))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* rule_identifiers_value = NULL;
  if (args.Get(1, &rule_identifiers_value) && !rule_identifiers_value->IsType(Value::TYPE_NULL))
  {
    {
      ListValue* list = NULL;
      if (!rule_identifiers_value->GetAsList(&list))
        return scoped_ptr<Params>();
      if (!json_schema_compiler::util::PopulateOptionalArrayFromList(*list, &params->rule_identifiers))
        return scoped_ptr<Params>();
    }
  }

  return params.Pass();
}


Value* Event::GetRules::Result::Create(const std::vector<linked_ptr<Rule> >& rules) {
  return json_schema_compiler::util::CreateValueFromArray(rules).release();
}

Event::RemoveRules::Params::Params() {}
Event::RemoveRules::Params::~Params() {}

// static
scoped_ptr<Event::RemoveRules::Params> Event::RemoveRules::Params::Create(const ListValue& args) {
  if (args.GetSize() < 1 || args.GetSize() > 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* event_name_value = NULL;
  if (args.Get(0, &event_name_value) && !event_name_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!event_name_value->GetAsString(&params->event_name))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* rule_identifiers_value = NULL;
  if (args.Get(1, &rule_identifiers_value) && !rule_identifiers_value->IsType(Value::TYPE_NULL))
  {
    {
      ListValue* list = NULL;
      if (!rule_identifiers_value->GetAsList(&list))
        return scoped_ptr<Params>();
      if (!json_schema_compiler::util::PopulateOptionalArrayFromList(*list, &params->rule_identifiers))
        return scoped_ptr<Params>();
    }
  }

  return params.Pass();
}


Value* Event::RemoveRules::Result::Create() {
  return Value::CreateNullValue();
}

Event::AddRules::Params::Params() {}
Event::AddRules::Params::~Params() {}

// static
scoped_ptr<Event::AddRules::Params> Event::AddRules::Params::Create(const ListValue& args) {
  if (args.GetSize() != 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* event_name_value = NULL;
  if (args.Get(0, &event_name_value) && !event_name_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!event_name_value->GetAsString(&params->event_name))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* rules_value = NULL;
  if (args.Get(1, &rules_value) && !rules_value->IsType(Value::TYPE_NULL))
  {
    {
      ListValue* list = NULL;
      if (!rules_value->GetAsList(&list))
        return scoped_ptr<Params>();
      if (!json_schema_compiler::util::PopulateArrayFromList(*list, &params->rules))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Event::AddRules::Result::Create(const std::vector<linked_ptr<Rule> >& rules) {
  return json_schema_compiler::util::CreateValueFromArray(rules).release();
}


Rule::Rule()
   {}
Rule::~Rule() {}

// static
bool Rule::Populate(const Value& value, Rule* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* priority_value = NULL;
  if (dict->GetWithoutPathExpansion("priority", &priority_value)) {
    {
      int temp;
      if (!priority_value->GetAsInteger(&temp))
        return false;
      out->priority.reset(new int(temp));
    }
  }

  Value* conditions_value = NULL;
  if (!dict->GetWithoutPathExpansion("conditions", &conditions_value))
    return false;
  {
    ListValue* list = NULL;
    if (!conditions_value->GetAsList(&list))
      return false;
    if (!json_schema_compiler::util::PopulateArrayFromList(*list, &out->conditions))
      return false;
  }

  Value* id_value = NULL;
  if (dict->GetWithoutPathExpansion("id", &id_value)) {
    {
      std::string temp;
      if (!id_value->GetAsString(&temp))
        return false;
      out->id.reset(new std::string(temp));
    }
  }

  Value* actions_value = NULL;
  if (!dict->GetWithoutPathExpansion("actions", &actions_value))
    return false;
  {
    ListValue* list = NULL;
    if (!actions_value->GetAsList(&list))
      return false;
    if (!json_schema_compiler::util::PopulateArrayFromList(*list, &out->actions))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> Rule::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  if (priority.get())
    value->SetWithoutPathExpansion("priority", Value::CreateIntegerValue(*this->priority));

  value->SetWithoutPathExpansion("conditions", json_schema_compiler::util::CreateValueFromArray(this->conditions).release());
  if (id.get())
    value->SetWithoutPathExpansion("id", Value::CreateStringValue(*this->id));

  value->SetWithoutPathExpansion("actions", json_schema_compiler::util::CreateValueFromArray(this->actions).release());

  return value.Pass();
}


}  // events
}  // api
}  // extensions
