// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/experimental_bluetooth.idl
// DO NOT EDIT.

#include "tools/json_schema_compiler/util.h"
#include "chrome/common/extensions/api/experimental_bluetooth.h"

using base::Value;
using base::DictionaryValue;
using base::ListValue;
using base::BinaryValue;
using json_schema_compiler::any::Any;

namespace extensions {
namespace api {
namespace experimental_bluetooth {

//
// Types
//

Socket::Socket()
  : id(0) {}
Socket::~Socket() {}

// static
bool Socket::Populate(const Value& value, Socket* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* device_value = NULL;
  if (!dict->GetWithoutPathExpansion("device", &device_value))
    return false;
  {
    DictionaryValue* dictionary = NULL;
    if (!device_value->GetAsDictionary(&dictionary))
      return false;
    if (!Device::Populate(*dictionary, &out->device))
      return false;
  }

  Value* service_uuid_value = NULL;
  if (!dict->GetWithoutPathExpansion("serviceUuid", &service_uuid_value))
    return false;
  {
    if (!service_uuid_value->GetAsString(&out->service_uuid))
      return false;
  }

  Value* id_value = NULL;
  if (!dict->GetWithoutPathExpansion("id", &id_value))
    return false;
  {
    if (!id_value->GetAsInteger(&out->id))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> Socket::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("device", this->device.ToValue().release());
  value->SetWithoutPathExpansion("serviceUuid", Value::CreateStringValue(this->service_uuid));
  value->SetWithoutPathExpansion("id", Value::CreateIntegerValue(this->id));

  return value.Pass();
}


WriteOptions::WriteOptions()
  : socket_id(0), data(NULL) {}
WriteOptions::~WriteOptions() {}

// static
bool WriteOptions::Populate(const Value& value, WriteOptions* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* socket_id_value = NULL;
  if (!dict->GetWithoutPathExpansion("socketId", &socket_id_value))
    return false;
  {
    if (!socket_id_value->GetAsInteger(&out->socket_id))
      return false;
  }

  Value* data_value = NULL;
  if (!dict->GetWithoutPathExpansion("data", &data_value))
    return false;
  {
    if (!data_value->IsType(Value::TYPE_BINARY))
      return false;
    out->data.reset(
        static_cast<BinaryValue*>(data_value)->DeepCopy());
  }

  return true;
}

scoped_ptr<DictionaryValue> WriteOptions::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("socketId", Value::CreateIntegerValue(this->socket_id));
  value->SetWithoutPathExpansion("data", this->data->DeepCopy());

  return value.Pass();
}


ServiceRecord::ServiceRecord()
   {}
ServiceRecord::~ServiceRecord() {}

// static
bool ServiceRecord::Populate(const Value& value, ServiceRecord* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* name_value = NULL;
  if (!dict->GetWithoutPathExpansion("name", &name_value))
    return false;
  {
    if (!name_value->GetAsString(&out->name))
      return false;
  }

  Value* uuid_value = NULL;
  if (dict->GetWithoutPathExpansion("uuid", &uuid_value)) {
    {
      std::string temp;
      if (!uuid_value->GetAsString(&temp))
        return false;
      out->uuid.reset(new std::string(temp));
    }
  }

  return true;
}

scoped_ptr<DictionaryValue> ServiceRecord::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("name", Value::CreateStringValue(this->name));
  if (uuid.get())
    value->SetWithoutPathExpansion("uuid", Value::CreateStringValue(*this->uuid));


  return value.Pass();
}


ConnectOptions::ConnectOptions()
   {}
ConnectOptions::~ConnectOptions() {}

// static
bool ConnectOptions::Populate(const Value& value, ConnectOptions* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* device_address_value = NULL;
  if (!dict->GetWithoutPathExpansion("deviceAddress", &device_address_value))
    return false;
  {
    if (!device_address_value->GetAsString(&out->device_address))
      return false;
  }

  Value* service_uuid_value = NULL;
  if (!dict->GetWithoutPathExpansion("serviceUuid", &service_uuid_value))
    return false;
  {
    if (!service_uuid_value->GetAsString(&out->service_uuid))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> ConnectOptions::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("deviceAddress", Value::CreateStringValue(this->device_address));
  value->SetWithoutPathExpansion("serviceUuid", Value::CreateStringValue(this->service_uuid));

  return value.Pass();
}


ReadOptions::ReadOptions()
  : socket_id(0) {}
ReadOptions::~ReadOptions() {}

// static
bool ReadOptions::Populate(const Value& value, ReadOptions* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* socket_id_value = NULL;
  if (!dict->GetWithoutPathExpansion("socketId", &socket_id_value))
    return false;
  {
    if (!socket_id_value->GetAsInteger(&out->socket_id))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> ReadOptions::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("socketId", Value::CreateIntegerValue(this->socket_id));

  return value.Pass();
}


GetServicesOptions::GetServicesOptions()
   {}
GetServicesOptions::~GetServicesOptions() {}

// static
bool GetServicesOptions::Populate(const Value& value, GetServicesOptions* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* device_address_value = NULL;
  if (!dict->GetWithoutPathExpansion("deviceAddress", &device_address_value))
    return false;
  {
    if (!device_address_value->GetAsString(&out->device_address))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> GetServicesOptions::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("deviceAddress", Value::CreateStringValue(this->device_address));

  return value.Pass();
}


SetOutOfBandPairingDataOptions::SetOutOfBandPairingDataOptions()
   {}
SetOutOfBandPairingDataOptions::~SetOutOfBandPairingDataOptions() {}

// static
bool SetOutOfBandPairingDataOptions::Populate(const Value& value, SetOutOfBandPairingDataOptions* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* data_value = NULL;
  if (dict->GetWithoutPathExpansion("data", &data_value)) {
    {
      DictionaryValue* dictionary = NULL;
      if (!data_value->GetAsDictionary(&dictionary))
        return false;
      scoped_ptr<OutOfBandPairingData> temp(new OutOfBandPairingData());
      if (!OutOfBandPairingData::Populate(*dictionary, temp.get()))
        return false;
      out->data = temp.Pass();
    }
  }

  Value* address_value = NULL;
  if (!dict->GetWithoutPathExpansion("address", &address_value))
    return false;
  {
    if (!address_value->GetAsString(&out->address))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> SetOutOfBandPairingDataOptions::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  if (data.get())
    value->SetWithoutPathExpansion("data", this->data->ToValue().release());

  value->SetWithoutPathExpansion("address", Value::CreateStringValue(this->address));

  return value.Pass();
}


Device::Device()
  : paired(false), connected(false), bonded(false) {}
Device::~Device() {}

// static
bool Device::Populate(const Value& value, Device* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* paired_value = NULL;
  if (!dict->GetWithoutPathExpansion("paired", &paired_value))
    return false;
  {
    if (!paired_value->GetAsBoolean(&out->paired))
      return false;
  }

  Value* connected_value = NULL;
  if (!dict->GetWithoutPathExpansion("connected", &connected_value))
    return false;
  {
    if (!connected_value->GetAsBoolean(&out->connected))
      return false;
  }

  Value* name_value = NULL;
  if (!dict->GetWithoutPathExpansion("name", &name_value))
    return false;
  {
    if (!name_value->GetAsString(&out->name))
      return false;
  }

  Value* bonded_value = NULL;
  if (!dict->GetWithoutPathExpansion("bonded", &bonded_value))
    return false;
  {
    if (!bonded_value->GetAsBoolean(&out->bonded))
      return false;
  }

  Value* address_value = NULL;
  if (!dict->GetWithoutPathExpansion("address", &address_value))
    return false;
  {
    if (!address_value->GetAsString(&out->address))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> Device::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("paired", Value::CreateBooleanValue(this->paired));
  value->SetWithoutPathExpansion("connected", Value::CreateBooleanValue(this->connected));
  value->SetWithoutPathExpansion("name", Value::CreateStringValue(this->name));
  value->SetWithoutPathExpansion("bonded", Value::CreateBooleanValue(this->bonded));
  value->SetWithoutPathExpansion("address", Value::CreateStringValue(this->address));

  return value.Pass();
}


DisconnectOptions::DisconnectOptions()
  : socket_id(0) {}
DisconnectOptions::~DisconnectOptions() {}

// static
bool DisconnectOptions::Populate(const Value& value, DisconnectOptions* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* socket_id_value = NULL;
  if (!dict->GetWithoutPathExpansion("socketId", &socket_id_value))
    return false;
  {
    if (!socket_id_value->GetAsInteger(&out->socket_id))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> DisconnectOptions::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("socketId", Value::CreateIntegerValue(this->socket_id));

  return value.Pass();
}


OutOfBandPairingData::OutOfBandPairingData()
  : hash(NULL), randomizer(NULL) {}
OutOfBandPairingData::~OutOfBandPairingData() {}

// static
bool OutOfBandPairingData::Populate(const Value& value, OutOfBandPairingData* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* hash_value = NULL;
  if (!dict->GetWithoutPathExpansion("hash", &hash_value))
    return false;
  {
    if (!hash_value->IsType(Value::TYPE_BINARY))
      return false;
    out->hash.reset(
        static_cast<BinaryValue*>(hash_value)->DeepCopy());
  }

  Value* randomizer_value = NULL;
  if (!dict->GetWithoutPathExpansion("randomizer", &randomizer_value))
    return false;
  {
    if (!randomizer_value->IsType(Value::TYPE_BINARY))
      return false;
    out->randomizer.reset(
        static_cast<BinaryValue*>(randomizer_value)->DeepCopy());
  }

  return true;
}

scoped_ptr<DictionaryValue> OutOfBandPairingData::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("hash", this->hash->DeepCopy());
  value->SetWithoutPathExpansion("randomizer", this->randomizer->DeepCopy());

  return value.Pass();
}


GetDevicesOptions::GetDevicesOptions()
   {}
GetDevicesOptions::~GetDevicesOptions() {}

// static
bool GetDevicesOptions::Populate(const Value& value, GetDevicesOptions* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* uuid_value = NULL;
  if (dict->GetWithoutPathExpansion("uuid", &uuid_value)) {
    {
      std::string temp;
      if (!uuid_value->GetAsString(&temp))
        return false;
      out->uuid.reset(new std::string(temp));
    }
  }

  Value* name_value = NULL;
  if (dict->GetWithoutPathExpansion("name", &name_value)) {
    {
      std::string temp;
      if (!name_value->GetAsString(&temp))
        return false;
      out->name.reset(new std::string(temp));
    }
  }

  return true;
}

scoped_ptr<DictionaryValue> GetDevicesOptions::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  if (uuid.get())
    value->SetWithoutPathExpansion("uuid", Value::CreateStringValue(*this->uuid));

  if (name.get())
    value->SetWithoutPathExpansion("name", Value::CreateStringValue(*this->name));


  return value.Pass();
}


StartDiscoveryOptions::StartDiscoveryOptions()
   {}
StartDiscoveryOptions::~StartDiscoveryOptions() {}

// static
bool StartDiscoveryOptions::Populate(const Value& value, StartDiscoveryOptions* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  return true;
}

scoped_ptr<DictionaryValue> StartDiscoveryOptions::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());


  return value.Pass();
}


//
// Functions
//

Value* IsPowered::Result::Create(const bool result) {
  return Value::CreateBooleanValue(result);
}

Disconnect::Params::Params() {}
Disconnect::Params::~Params() {}

// static
scoped_ptr<Disconnect::Params> Disconnect::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* options_value = NULL;
  if (args.Get(0, &options_value) && !options_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!options_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!DisconnectOptions::Populate(*dictionary, &params->options))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Disconnect::Result::Create() {
  return Value::CreateNullValue();
}

Read::Params::Params() {}
Read::Params::~Params() {}

// static
scoped_ptr<Read::Params> Read::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* options_value = NULL;
  if (args.Get(0, &options_value) && !options_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!options_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!ReadOptions::Populate(*dictionary, &params->options))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Read::Result::Create(const scoped_ptr<base::BinaryValue> result) {
  return result->DeepCopy();
}

SetOutOfBandPairingData::Params::Params() {}
SetOutOfBandPairingData::Params::~Params() {}

// static
scoped_ptr<SetOutOfBandPairingData::Params> SetOutOfBandPairingData::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* options_value = NULL;
  if (args.Get(0, &options_value) && !options_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!options_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!SetOutOfBandPairingDataOptions::Populate(*dictionary, &params->options))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* SetOutOfBandPairingData::Result::Create() {
  return Value::CreateNullValue();
}

Value* GetAddress::Result::Create(const std::string& result) {
  return Value::CreateStringValue(result);
}

GetDevices::Params::Params() {}
GetDevices::Params::~Params() {}

// static
scoped_ptr<GetDevices::Params> GetDevices::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* options_value = NULL;
  if (args.Get(0, &options_value) && !options_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!options_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!GetDevicesOptions::Populate(*dictionary, &params->options))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* GetDevices::Result::Create(const std::vector<linked_ptr<Device> >& result) {
  return json_schema_compiler::util::CreateValueFromArray(result).release();
}

Write::Params::Params() {}
Write::Params::~Params() {}

// static
scoped_ptr<Write::Params> Write::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* options_value = NULL;
  if (args.Get(0, &options_value) && !options_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!options_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!WriteOptions::Populate(*dictionary, &params->options))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Write::Result::Create(const int result) {
  return Value::CreateIntegerValue(result);
}

Value* GetLocalOutOfBandPairingData::Result::Create(const OutOfBandPairingData& data) {
  return data.ToValue().release();
}

Connect::Params::Params() {}
Connect::Params::~Params() {}

// static
scoped_ptr<Connect::Params> Connect::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* options_value = NULL;
  if (args.Get(0, &options_value) && !options_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!options_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!ConnectOptions::Populate(*dictionary, &params->options))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Connect::Result::Create(const Socket& result) {
  return result.ToValue().release();
}

GetServices::Params::Params() {}
GetServices::Params::~Params() {}

// static
scoped_ptr<GetServices::Params> GetServices::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* options_value = NULL;
  if (args.Get(0, &options_value) && !options_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!options_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!GetServicesOptions::Populate(*dictionary, &params->options))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* GetServices::Result::Create(const std::vector<linked_ptr<ServiceRecord> >& result) {
  return json_schema_compiler::util::CreateValueFromArray(result).release();
}

Value* IsAvailable::Result::Create(const bool result) {
  return Value::CreateBooleanValue(result);
}

StartDiscovery::Params::Params() {}
StartDiscovery::Params::~Params() {}

// static
scoped_ptr<StartDiscovery::Params> StartDiscovery::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* options_value = NULL;
  if (args.Get(0, &options_value) && !options_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!options_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!StartDiscoveryOptions::Populate(*dictionary, &params->options))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* StartDiscovery::Result::Create() {
  return Value::CreateNullValue();
}

Value* StopDiscovery::Result::Create() {
  return Value::CreateNullValue();
}

}  // experimental_bluetooth
}  // api
}  // extensions
