// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/experimental_bluetooth.idl
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_BLUETOOTH_H__
#define CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_BLUETOOTH_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace experimental_bluetooth {
struct Socket;
struct WriteOptions;
struct ServiceRecord;
struct ConnectOptions;
struct ReadOptions;
struct GetServicesOptions;
struct SetOutOfBandPairingDataOptions;
struct Device;
struct DisconnectOptions;
struct OutOfBandPairingData;
struct GetDevicesOptions;
struct StartDiscoveryOptions;
}  // experimental_bluetooth

namespace experimental_bluetooth {

//
// Types
//

struct Device {
  ~Device();
  Device();

  // Indicates whether or not the device is paired with the system.
  bool paired;

  // Indicates whether the device is currently connected to the system.
  bool connected;

  // The human-readable name of the device.
  std::string name;

  // Indicates whether or not the device is bonded with the system. A device is
  // bonded if it is paired and high-security link keys have been exchanged so
  // that connections may be encrypted.
  bool bonded;

  // The address of the device, in the format 'XX:XX:XX:XX:XX:XX'.
  std::string address;

  // Populates a Device object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, Device* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // Device object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(Device);
};

struct Socket {
  ~Socket();
  Socket();

  Device device;

  std::string service_uuid;

  int id;

  // Populates a Socket object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, Socket* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // Socket object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(Socket);
};

struct WriteOptions {
  ~WriteOptions();
  WriteOptions();

  // The socket to write to.
  int socket_id;

  // The data to write.
  scoped_ptr<base::BinaryValue> data;

  // Populates a WriteOptions object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, WriteOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // WriteOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(WriteOptions);
};

struct ServiceRecord {
  ~ServiceRecord();
  ServiceRecord();

  // The name of the service.
  std::string name;

  // The UUID of the service.
  scoped_ptr<std::string> uuid;

  // Populates a ServiceRecord object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, ServiceRecord* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ServiceRecord object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ServiceRecord);
};

struct ConnectOptions {
  ~ConnectOptions();
  ConnectOptions();

  // The connection is made to the device at |deviceAddress|. |deviceAddress|
  // should be in the format 'XX:XX:XX:XX:XX:XX'.
  std::string device_address;

  // The connection is made to the service with UUID |serviceUuid|.
  std::string service_uuid;

  // Populates a ConnectOptions object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, ConnectOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ConnectOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ConnectOptions);
};

struct ReadOptions {
  ~ReadOptions();
  ReadOptions();

  // The socket to read from.
  int socket_id;

  // Populates a ReadOptions object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, ReadOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ReadOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ReadOptions);
};

struct GetServicesOptions {
  ~GetServicesOptions();
  GetServicesOptions();

  // The address of the device to inquire about. |deviceAddress| should be in the
  // format 'XX:XX:XX:XX:XX:XX'.
  std::string device_address;

  // Populates a GetServicesOptions object from a Value. Returns whether |out|
  // was successfully populated.
  static bool Populate(const Value& value, GetServicesOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // GetServicesOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(GetServicesOptions);
};

struct SetOutOfBandPairingDataOptions {
  ~SetOutOfBandPairingDataOptions();
  SetOutOfBandPairingDataOptions();

  // The Out Of Band Pairing Data. If this is omitted, the data for the device is
  // cleared instead.
  scoped_ptr<OutOfBandPairingData> data;

  // The address of the remote device that the data should be associated with.
  // |deviceAddress| should be in the format 'XX:XX:XX:XX:XX:XX'.
  std::string address;

  // Populates a SetOutOfBandPairingDataOptions object from a Value. Returns
  // whether |out| was successfully populated.
  static bool Populate(const Value& value, SetOutOfBandPairingDataOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // SetOutOfBandPairingDataOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(SetOutOfBandPairingDataOptions);
};

struct DisconnectOptions {
  ~DisconnectOptions();
  DisconnectOptions();

  // The socket to disconnect.
  int socket_id;

  // Populates a DisconnectOptions object from a Value. Returns whether |out|
  // was successfully populated.
  static bool Populate(const Value& value, DisconnectOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // DisconnectOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(DisconnectOptions);
};

struct OutOfBandPairingData {
  ~OutOfBandPairingData();
  OutOfBandPairingData();

  // Simple Pairing Hash C. Always 16 octets long.
  scoped_ptr<base::BinaryValue> hash;

  // Simple Pairing Randomizer R. Always 16 octets long.
  scoped_ptr<base::BinaryValue> randomizer;

  // Populates a OutOfBandPairingData object from a Value. Returns whether
  // |out| was successfully populated.
  static bool Populate(const Value& value, OutOfBandPairingData* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // OutOfBandPairingData object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(OutOfBandPairingData);
};

struct GetDevicesOptions {
  ~GetDevicesOptions();
  GetDevicesOptions();

  // Only devices providing a service with a UUID that matches |uuid| will be
  // returned.
  scoped_ptr<std::string> uuid;

  // Only devices providing a service with a name that matches |name| will be
  // returned.
  scoped_ptr<std::string> name;

  // Populates a GetDevicesOptions object from a Value. Returns whether |out|
  // was successfully populated.
  static bool Populate(const Value& value, GetDevicesOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // GetDevicesOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(GetDevicesOptions);
};

struct StartDiscoveryOptions {
  ~StartDiscoveryOptions();
  StartDiscoveryOptions();

  // Populates a StartDiscoveryOptions object from a Value. Returns whether
  // |out| was successfully populated.
  static bool Populate(const Value& value, StartDiscoveryOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // StartDiscoveryOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(StartDiscoveryOptions);
};

//
// Functions
//

namespace IsPowered {

  namespace Result {
    Value* Create(const bool result);
  };

};

namespace Disconnect {
  struct Params {
    // The options for this function.
    DisconnectOptions options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace Read {
  struct Params {
    // The options for this function.
    ReadOptions options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const scoped_ptr<base::BinaryValue> result);
  };

};

namespace SetOutOfBandPairingData {
  struct Params {
    // The options for this function.
    SetOutOfBandPairingDataOptions options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace GetAddress {

  namespace Result {
    Value* Create(const std::string& result);
  };

};

namespace GetDevices {
  struct Params {
    // Controls which devices are returned.
    GetDevicesOptions options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {

    Value* Create(const std::vector<linked_ptr<Device> >& result);
  };

};

namespace Write {
  struct Params {
    // The options for this function.
    WriteOptions options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const int result);
  };

};

namespace GetLocalOutOfBandPairingData {

  namespace Result {
    Value* Create(const OutOfBandPairingData& data);
  };

};

namespace Connect {
  struct Params {
    // The options for the connection.
    ConnectOptions options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const Socket& result);
  };

};

namespace GetServices {
  struct Params {
    GetServicesOptions options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {

    Value* Create(const std::vector<linked_ptr<ServiceRecord> >& result);
  };

};

namespace IsAvailable {

  namespace Result {
    Value* Create(const bool result);
  };

};

namespace StartDiscovery {
  struct Params {
    // The options for this function.
    StartDiscoveryOptions options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace StopDiscovery {

  namespace Result {
    Value* Create();
  };

};

}  // experimental_bluetooth
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_BLUETOOTH_H__
