// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/experimental_font_settings.json
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_FONT_SETTINGS_H__
#define CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_FONT_SETTINGS_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace experimental_font_settings {
struct FontName;
}  // experimental_font_settings

namespace experimental_font_settings {

//
// Types
//

// Represents a font name.
struct FontName {
  ~FontName();
  FontName();

  // The font name.
  std::string font_name;

  // The font name localized for the current locale.
  std::string localized_name;

  // Populates a FontName object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, FontName* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // FontName object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(FontName);
};

// An ISO 15924 script code. The default, or global, script is represented by
// script code "Zyyy".
typedef std::string ScriptCode;

// One of<br><var>not_controllable</var>: cannot be controlled by any
// extension<br><var>controlled_by_other_extensions</var>: controlled by
// extensions with higher
// precedence<br><var>controllable_by_this_extension</var>: can be controlled
// by this extension<br><var>controlled_by_this_extension</var>: controlled by
// this extension
typedef std::string LevelOfControl;

// A CSS generic font family.
typedef std::string GenericFamily;

//
// Functions
//

namespace SetDefaultFontSize {
  struct Params {
    struct Details {
      ~Details();
      Details();

      // The font size in pixels.
      int pixel_size;

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Details details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace GetFont {
  struct Params {
    struct Details {
      ~Details();
      Details();

      // The generic font family for which the font should be retrieved.
      GenericFamily generic_family;

      // The script for which the font should be retrieved. If omitted, the font
      // setting for the global script (script code "Zyyy") is retrieved.
      scoped_ptr<ScriptCode> script;

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Details details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    struct Details {
      ~Details();
      Details();

      // The font name. Rather than the literal font name preference value, this may
      // be the name of the font that the system resolves the preference value to.
      // The empty string signifies fallback to the global script font setting.
      std::string font_name;

      // The level of control this extension has over the setting.
      LevelOfControl level_of_control;

      // Returns a new DictionaryValue representing the serialized form of this
      // Details object. Passes ownership to caller.
      scoped_ptr<DictionaryValue> ToValue() const;

     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Value* Create(const Details& details);
  };

};

namespace GetDefaultFontSize {
  struct Params {
    // This parameter is currently unused.
    struct Details {
      ~Details();
      Details();

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    // This parameter is currently unused.
    scoped_ptr<Details> details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    struct Details {
      ~Details();
      Details();

      // The font size in pixels.
      int pixel_size;

      // The level of control this extension has over the setting.
      LevelOfControl level_of_control;

      // Returns a new DictionaryValue representing the serialized form of this
      // Details object. Passes ownership to caller.
      scoped_ptr<DictionaryValue> ToValue() const;

     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Value* Create(const Details& details);
  };

};

namespace GetMinimumFontSize {
  struct Params {
    // This parameter is currently unused.
    struct Details {
      ~Details();
      Details();

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    // This parameter is currently unused.
    scoped_ptr<Details> details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    struct Details {
      ~Details();
      Details();

      // The font size in pixels.
      int pixel_size;

      // The level of control this extension has over the setting.
      LevelOfControl level_of_control;

      // Returns a new DictionaryValue representing the serialized form of this
      // Details object. Passes ownership to caller.
      scoped_ptr<DictionaryValue> ToValue() const;

     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Value* Create(const Details& details);
  };

};

namespace SetMinimumFontSize {
  struct Params {
    struct Details {
      ~Details();
      Details();

      // The font size in pixels.
      int pixel_size;

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Details details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace GetDefaultFixedFontSize {
  struct Params {
    // This parameter is currently unused.
    struct Details {
      ~Details();
      Details();

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    // This parameter is currently unused.
    scoped_ptr<Details> details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    struct Details {
      ~Details();
      Details();

      // The font size in pixels.
      int pixel_size;

      // The level of control this extension has over the setting.
      LevelOfControl level_of_control;

      // Returns a new DictionaryValue representing the serialized form of this
      // Details object. Passes ownership to caller.
      scoped_ptr<DictionaryValue> ToValue() const;

     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Value* Create(const Details& details);
  };

};

namespace ClearDefaultFontSize {
  struct Params {
    // This parameter is currently unused.
    struct Details {
      ~Details();
      Details();

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    // This parameter is currently unused.
    scoped_ptr<Details> details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace SetDefaultFixedFontSize {
  struct Params {
    struct Details {
      ~Details();
      Details();

      // The font size in pixels.
      int pixel_size;

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Details details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace ClearFont {
  struct Params {
    struct Details {
      ~Details();
      Details();

      // The generic font family for which the font should be cleared.
      GenericFamily generic_family;

      // The script for which the font should be cleared. If omitted, the global
      // script font setting is cleared.
      scoped_ptr<ScriptCode> script;

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Details details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace SetFont {
  struct Params {
    struct Details {
      ~Details();
      Details();

      // The font name. If a script is specified, the empty string means to fallback
      // to the global script font setting.
      std::string font_name;

      // The generic font family for which the font should be set.
      GenericFamily generic_family;

      // The script code which the font should be set. If omitted, the font setting
      // for the global script (script code "Zyyy") is set.
      scoped_ptr<ScriptCode> script;

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    Details details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace ClearMinimumFontSize {
  struct Params {
    // This parameter is currently unused.
    struct Details {
      ~Details();
      Details();

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    // This parameter is currently unused.
    scoped_ptr<Details> details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace GetFontList {

  namespace Result {

    Value* Create(const std::vector<linked_ptr<FontName> >& results);
  };

};

namespace ClearDefaultFixedFontSize {
  struct Params {
    // This parameter is currently unused.
    struct Details {
      ~Details();
      Details();

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    // This parameter is currently unused.
    scoped_ptr<Details> details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

}  // experimental_font_settings
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_FONT_SETTINGS_H__
