// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/experimental_record.json
// DO NOT EDIT.

#include "tools/json_schema_compiler/util.h"
#include "chrome/common/extensions/api/experimental_record.h"

using base::Value;
using base::DictionaryValue;
using base::ListValue;
using base::BinaryValue;
using json_schema_compiler::any::Any;

namespace extensions {
namespace api {
namespace experimental_record {

//
// Types
//

ReplayURLsResult::ReplayURLsResult()
  : run_time(0) {}
ReplayURLsResult::~ReplayURLsResult() {}

// static
bool ReplayURLsResult::Populate(const Value& value, ReplayURLsResult* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* run_time_value = NULL;
  if (!dict->GetWithoutPathExpansion("runTime", &run_time_value))
    return false;
  {
    if (!run_time_value->GetAsInteger(&out->run_time))
      return false;
  }

  Value* stats_value = NULL;
  if (!dict->GetWithoutPathExpansion("stats", &stats_value))
    return false;
  {
    if (!stats_value->GetAsString(&out->stats))
      return false;
  }

  Value* errors_value = NULL;
  if (!dict->GetWithoutPathExpansion("errors", &errors_value))
    return false;
  {
    ListValue* list = NULL;
    if (!errors_value->GetAsList(&list))
      return false;
    if (!json_schema_compiler::util::PopulateArrayFromList(*list, &out->errors))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> ReplayURLsResult::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("runTime", Value::CreateIntegerValue(this->run_time));
  value->SetWithoutPathExpansion("stats", Value::CreateStringValue(this->stats));
  value->SetWithoutPathExpansion("errors", json_schema_compiler::util::CreateValueFromArray(this->errors).release());

  return value.Pass();
}


SessionDetails::SessionDetails()
   {}
SessionDetails::~SessionDetails() {}

// static
bool SessionDetails::Populate(const Value& value, SessionDetails* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* extension_path_value = NULL;
  if (dict->GetWithoutPathExpansion("extensionPath", &extension_path_value)) {
    {
      std::string temp;
      if (!extension_path_value->GetAsString(&temp))
        return false;
      out->extension_path.reset(new std::string(temp));
    }
  }

  return true;
}

scoped_ptr<DictionaryValue> SessionDetails::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  if (extension_path.get())
    value->SetWithoutPathExpansion("extensionPath", Value::CreateStringValue(*this->extension_path));


  return value.Pass();
}


//
// Functions
//

ReplayURLs::Params::Params() {}
ReplayURLs::Params::~Params() {}

// static
scoped_ptr<ReplayURLs::Params> ReplayURLs::Params::Create(const ListValue& args) {
  if (args.GetSize() < 3 || args.GetSize() > 4)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* urls_value = NULL;
  if (args.Get(0, &urls_value) && !urls_value->IsType(Value::TYPE_NULL))
  {
    {
      ListValue* list = NULL;
      if (!urls_value->GetAsList(&list))
        return scoped_ptr<Params>();
      if (!json_schema_compiler::util::PopulateArrayFromList(*list, &params->urls))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* capture_directory_path_value = NULL;
  if (args.Get(1, &capture_directory_path_value) && !capture_directory_path_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!capture_directory_path_value->GetAsString(&params->capture_directory_path))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* repeat_count_value = NULL;
  if (args.Get(2, &repeat_count_value) && !repeat_count_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!repeat_count_value->GetAsInteger(&params->repeat_count))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* details_value = NULL;
  if (args.Get(3, &details_value) && !details_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!details_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      scoped_ptr<SessionDetails> temp(new SessionDetails());
      if (!SessionDetails::Populate(*dictionary, temp.get()))
        return scoped_ptr<Params>();
      params->details = temp.Pass();
    }
  }

  return params.Pass();
}


Value* ReplayURLs::Result::Create(const ReplayURLsResult& result) {
  return result.ToValue().release();
}

CaptureURLs::Params::Params() {}
CaptureURLs::Params::~Params() {}

// static
scoped_ptr<CaptureURLs::Params> CaptureURLs::Params::Create(const ListValue& args) {
  if (args.GetSize() != 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* urls_value = NULL;
  if (args.Get(0, &urls_value) && !urls_value->IsType(Value::TYPE_NULL))
  {
    {
      ListValue* list = NULL;
      if (!urls_value->GetAsList(&list))
        return scoped_ptr<Params>();
      if (!json_schema_compiler::util::PopulateArrayFromList(*list, &params->urls))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* cache_directory_path_value = NULL;
  if (args.Get(1, &cache_directory_path_value) && !cache_directory_path_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!cache_directory_path_value->GetAsString(&params->cache_directory_path))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* CaptureURLs::Result::Create(const std::vector<std::string>& errors) {
  return json_schema_compiler::util::CreateValueFromArray(errors).release();
}

}  // experimental_record
}  // api
}  // extensions
