// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/experimental_serial.idl
// DO NOT EDIT.

#include "tools/json_schema_compiler/util.h"
#include "chrome/common/extensions/api/experimental_serial.h"

using base::Value;
using base::DictionaryValue;
using base::ListValue;
using base::BinaryValue;
using json_schema_compiler::any::Any;

namespace extensions {
namespace api {
namespace experimental_serial {

//
// Types
//

WriteInfo::WriteInfo()
  : bytes_written(0) {}
WriteInfo::~WriteInfo() {}

// static
bool WriteInfo::Populate(const Value& value, WriteInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* bytes_written_value = NULL;
  if (!dict->GetWithoutPathExpansion("bytesWritten", &bytes_written_value))
    return false;
  {
    if (!bytes_written_value->GetAsInteger(&out->bytes_written))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> WriteInfo::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("bytesWritten", Value::CreateIntegerValue(this->bytes_written));

  return value.Pass();
}


ReadInfo::ReadInfo()
  : bytes_read(0), data(NULL) {}
ReadInfo::~ReadInfo() {}

// static
bool ReadInfo::Populate(const Value& value, ReadInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* bytes_read_value = NULL;
  if (!dict->GetWithoutPathExpansion("bytesRead", &bytes_read_value))
    return false;
  {
    if (!bytes_read_value->GetAsInteger(&out->bytes_read))
      return false;
  }

  Value* data_value = NULL;
  if (!dict->GetWithoutPathExpansion("data", &data_value))
    return false;
  {
    if (!data_value->IsType(Value::TYPE_BINARY))
      return false;
    out->data.reset(
        static_cast<BinaryValue*>(data_value)->DeepCopy());
  }

  return true;
}

scoped_ptr<DictionaryValue> ReadInfo::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("bytesRead", Value::CreateIntegerValue(this->bytes_read));
  value->SetWithoutPathExpansion("data", this->data->DeepCopy());

  return value.Pass();
}


OpenInfo::OpenInfo()
  : connection_id(0) {}
OpenInfo::~OpenInfo() {}

// static
bool OpenInfo::Populate(const Value& value, OpenInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* connection_id_value = NULL;
  if (!dict->GetWithoutPathExpansion("connectionId", &connection_id_value))
    return false;
  {
    if (!connection_id_value->GetAsInteger(&out->connection_id))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> OpenInfo::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("connectionId", Value::CreateIntegerValue(this->connection_id));

  return value.Pass();
}


//
// Functions
//

Read::Params::Params() {}
Read::Params::~Params() {}

// static
scoped_ptr<Read::Params> Read::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* connection_id_value = NULL;
  if (args.Get(0, &connection_id_value) && !connection_id_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!connection_id_value->GetAsInteger(&params->connection_id))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Read::Result::Create(const ReadInfo& read_info) {
  return read_info.ToValue().release();
}

Value* GetPorts::Result::Create(const std::vector<std::string>& ports) {
  return json_schema_compiler::util::CreateValueFromArray(ports).release();
}

Write::Params::Params() {}
Write::Params::~Params() {}

// static
scoped_ptr<Write::Params> Write::Params::Create(const ListValue& args) {
  if (args.GetSize() != 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* connection_id_value = NULL;
  if (args.Get(0, &connection_id_value) && !connection_id_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!connection_id_value->GetAsInteger(&params->connection_id))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* data_value = NULL;
  if (args.Get(1, &data_value) && !data_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!data_value->IsType(Value::TYPE_BINARY))
        return scoped_ptr<Params>();
      params->data.reset(
          static_cast<BinaryValue*>(data_value)->DeepCopy());
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Write::Result::Create(const WriteInfo& write_info) {
  return write_info.ToValue().release();
}

Flush::Params::Params() {}
Flush::Params::~Params() {}

// static
scoped_ptr<Flush::Params> Flush::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* connection_id_value = NULL;
  if (args.Get(0, &connection_id_value) && !connection_id_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!connection_id_value->GetAsInteger(&params->connection_id))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Flush::Result::Create(const bool result) {
  return Value::CreateBooleanValue(result);
}

Close::Params::Params() {}
Close::Params::~Params() {}

// static
scoped_ptr<Close::Params> Close::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* connection_id_value = NULL;
  if (args.Get(0, &connection_id_value) && !connection_id_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!connection_id_value->GetAsInteger(&params->connection_id))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Close::Result::Create(const bool result) {
  return Value::CreateBooleanValue(result);
}

Open::Params::Params() {}
Open::Params::~Params() {}

// static
scoped_ptr<Open::Params> Open::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* port_value = NULL;
  if (args.Get(0, &port_value) && !port_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!port_value->GetAsString(&params->port))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Open::Result::Create(const OpenInfo& open_info) {
  return open_info.ToValue().release();
}

}  // experimental_serial
}  // api
}  // extensions
