// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/experimental_serial.idl
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_SERIAL_H__
#define CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_SERIAL_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace experimental_serial {
struct WriteInfo;
struct ReadInfo;
struct OpenInfo;
}  // experimental_serial

namespace experimental_serial {

//
// Types
//

struct WriteInfo {
  ~WriteInfo();
  WriteInfo();

  // The number of bytes written.
  int bytes_written;

  // Populates a WriteInfo object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, WriteInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // WriteInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(WriteInfo);
};

struct ReadInfo {
  ~ReadInfo();
  ReadInfo();

  // The number of bytes received, or a negative number if an error occurred.
  int bytes_read;

  // The data received.
  scoped_ptr<base::BinaryValue> data;

  // Populates a ReadInfo object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, ReadInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ReadInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ReadInfo);
};

struct OpenInfo {
  ~OpenInfo();
  OpenInfo();

  // The id of the opened connection.
  int connection_id;

  // Populates a OpenInfo object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, OpenInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // OpenInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(OpenInfo);
};

//
// Functions
//

namespace Read {
  struct Params {
    // The id of the connection.
    int connection_id;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const ReadInfo& read_info);
  };

};

namespace GetPorts {

  namespace Result {

    Value* Create(const std::vector<std::string>& ports);
  };

};

namespace Write {
  struct Params {
    // The id of the connection.
    int connection_id;

    // The string to write.
    scoped_ptr<base::BinaryValue> data;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const WriteInfo& write_info);
  };

};

namespace Flush {
  struct Params {
    // The id of the connection.
    int connection_id;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const bool result);
  };

};

namespace Close {
  struct Params {
    // The id of the opened connection.
    int connection_id;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const bool result);
  };

};

namespace Open {
  struct Params {
    // The name of the serial port to open.
    std::string port;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const OpenInfo& open_info);
  };

};

}  // experimental_serial
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_SERIAL_H__
