// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/experimental_socket.idl
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_SOCKET_H__
#define CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_SOCKET_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace experimental_socket {
struct CreateOptions;
struct CreateInfo;
struct ReadInfo;
struct WriteInfo;
struct RecvFromInfo;
}  // experimental_socket

namespace experimental_socket {

//
// Types
//

struct CreateOptions {
  ~CreateOptions();
  CreateOptions();

  // The schema generator does not support dictionaries without any fields.
  // Ignore this field.
  scoped_ptr<int> dummy_value;

  // Populates a CreateOptions object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, CreateOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // CreateOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(CreateOptions);
};

struct CreateInfo {
  ~CreateInfo();
  CreateInfo();

  // The id of the newly created socket.
  int socket_id;

  // Populates a CreateInfo object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, CreateInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // CreateInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(CreateInfo);
};

struct ReadInfo {
  ~ReadInfo();
  ReadInfo();

  // The resultCode returned from the underlying read() call.
  int result_code;

  scoped_ptr<base::BinaryValue> data;

  // Populates a ReadInfo object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, ReadInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ReadInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ReadInfo);
};

struct WriteInfo {
  ~WriteInfo();
  WriteInfo();

  // The number of bytes sent, or a negative error code.
  int bytes_written;

  // Populates a WriteInfo object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, WriteInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // WriteInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(WriteInfo);
};

struct RecvFromInfo {
  ~RecvFromInfo();
  RecvFromInfo();

  // The resultCode returned from the underlying read() call.
  int result_code;

  scoped_ptr<base::BinaryValue> data;

  int port;

  std::string address;

  // Populates a RecvFromInfo object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, RecvFromInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // RecvFromInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(RecvFromInfo);
};

typedef std::string SocketType;

//
// Functions
//

namespace RecvFrom {
  struct Params {
    // The socketId.
    int socket_id;

    // The receive buffer size.
    scoped_ptr<int> buffer_size;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const RecvFromInfo& recv_from_info);
  };

};

namespace Disconnect {
  struct Params {
    // The socketId.
    int socket_id;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

};

namespace Read {
  struct Params {
    // The socketId.
    int socket_id;

    // The read buffer size.
    scoped_ptr<int> buffer_size;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const ReadInfo& read_info);
  };

};

namespace Bind {
  struct Params {
    // The socketId.
    int socket_id;

    // The address of the local machine.
    std::string address;

    // The port of the local machine.
    int port;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const int result);
  };

};

namespace Create {
  struct Params {
    // The type of socket to create. Must be <code>tcp</code> or <code>udp</code>.
    SocketType type;

    // The socket options.
    scoped_ptr<CreateOptions> options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const CreateInfo& create_info);
  };

};

namespace Write {
  struct Params {
    // The socketId.
    int socket_id;

    // The data to write.
    scoped_ptr<base::BinaryValue> data;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const WriteInfo& write_info);
  };

};

namespace SetNoDelay {
  struct Params {
    // The socketId.
    int socket_id;

    // If true, disable Nagle algorithm.
    bool no_delay;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const bool result);
  };

};

namespace Connect {
  struct Params {
    // The socketId.
    int socket_id;

    // The hostname or IP address of the remote machine.
    std::string hostname;

    // The port of the remote machine.
    int port;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const int result);
  };

};

namespace SendTo {
  struct Params {
    // The socketId.
    int socket_id;

    // The data to write.
    scoped_ptr<base::BinaryValue> data;

    // The address of the remote machine.
    std::string address;

    // The port of the remote machine.
    int port;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const WriteInfo& write_info);
  };

};

namespace Destroy {
  struct Params {
    // The socketId.
    int socket_id;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

};

namespace SetKeepAlive {
  struct Params {
    // The socketId.
    int socket_id;

    // If true, enable keep-alive functionality.
    bool enable;

    // Set the delay seconds between the last data packet received and the first
    // keepalive probe. Default is 0.
    scoped_ptr<int> delay;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const bool result);
  };

};

}  // experimental_socket
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_SOCKET_H__
