// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/experimental_usb.idl
// DO NOT EDIT.

#include "tools/json_schema_compiler/util.h"
#include "chrome/common/extensions/api/experimental_usb.h"

using base::Value;
using base::DictionaryValue;
using base::ListValue;
using base::BinaryValue;
using json_schema_compiler::any::Any;

namespace extensions {
namespace api {
namespace experimental_usb {

//
// Types
//

Device::Device()
  : vendor_id(0), handle(0), product_id(0) {}
Device::~Device() {}

// static
bool Device::Populate(const Value& value, Device* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* vendor_id_value = NULL;
  if (!dict->GetWithoutPathExpansion("vendorId", &vendor_id_value))
    return false;
  {
    if (!vendor_id_value->GetAsInteger(&out->vendor_id))
      return false;
  }

  Value* handle_value = NULL;
  if (!dict->GetWithoutPathExpansion("handle", &handle_value))
    return false;
  {
    if (!handle_value->GetAsInteger(&out->handle))
      return false;
  }

  Value* product_id_value = NULL;
  if (!dict->GetWithoutPathExpansion("productId", &product_id_value))
    return false;
  {
    if (!product_id_value->GetAsInteger(&out->product_id))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> Device::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("vendorId", Value::CreateIntegerValue(this->vendor_id));
  value->SetWithoutPathExpansion("handle", Value::CreateIntegerValue(this->handle));
  value->SetWithoutPathExpansion("productId", Value::CreateIntegerValue(this->product_id));

  return value.Pass();
}


DeviceOptions::DeviceOptions()
   {}
DeviceOptions::~DeviceOptions() {}

// static
bool DeviceOptions::Populate(const Value& value, DeviceOptions* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  return true;
}

scoped_ptr<DictionaryValue> DeviceOptions::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());


  return value.Pass();
}


IsochronousTransferInfo::IsochronousTransferInfo()
  : packet_length(0), packets(0) {}
IsochronousTransferInfo::~IsochronousTransferInfo() {}

// static
bool IsochronousTransferInfo::Populate(const Value& value, IsochronousTransferInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* packet_length_value = NULL;
  if (!dict->GetWithoutPathExpansion("packetLength", &packet_length_value))
    return false;
  {
    if (!packet_length_value->GetAsInteger(&out->packet_length))
      return false;
  }

  Value* transfer_info_value = NULL;
  if (!dict->GetWithoutPathExpansion("transferInfo", &transfer_info_value))
    return false;
  {
    DictionaryValue* dictionary = NULL;
    if (!transfer_info_value->GetAsDictionary(&dictionary))
      return false;
    if (!GenericTransferInfo::Populate(*dictionary, &out->transfer_info))
      return false;
  }

  Value* packets_value = NULL;
  if (!dict->GetWithoutPathExpansion("packets", &packets_value))
    return false;
  {
    if (!packets_value->GetAsInteger(&out->packets))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> IsochronousTransferInfo::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("packetLength", Value::CreateIntegerValue(this->packet_length));
  value->SetWithoutPathExpansion("transferInfo", this->transfer_info.ToValue().release());
  value->SetWithoutPathExpansion("packets", Value::CreateIntegerValue(this->packets));

  return value.Pass();
}


UsbEvent::UsbEvent()
  : src_id(0), is_final_event(false) {}
UsbEvent::~UsbEvent() {}

// static
bool UsbEvent::Populate(const Value& value, UsbEvent* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* data_value = NULL;
  if (dict->GetWithoutPathExpansion("data", &data_value)) {
    {
      if (!data_value->IsType(Value::TYPE_BINARY))
        return false;
      out->data.reset(
          static_cast<BinaryValue*>(data_value)->DeepCopy());
    }
  }

  Value* src_id_value = NULL;
  if (!dict->GetWithoutPathExpansion("srcId", &src_id_value))
    return false;
  {
    if (!src_id_value->GetAsInteger(&out->src_id))
      return false;
  }

  Value* is_final_event_value = NULL;
  if (!dict->GetWithoutPathExpansion("isFinalEvent", &is_final_event_value))
    return false;
  {
    if (!is_final_event_value->GetAsBoolean(&out->is_final_event))
      return false;
  }

  Value* error_value = NULL;
  if (dict->GetWithoutPathExpansion("error", &error_value)) {
    {
      std::string temp;
      if (!error_value->GetAsString(&temp))
        return false;
      out->error.reset(new std::string(temp));
    }
  }

  Value* result_code_value = NULL;
  if (dict->GetWithoutPathExpansion("resultCode", &result_code_value)) {
    {
      int temp;
      if (!result_code_value->GetAsInteger(&temp))
        return false;
      out->result_code.reset(new int(temp));
    }
  }

  Value* type_value = NULL;
  if (!dict->GetWithoutPathExpansion("type", &type_value))
    return false;
  {
    if (!type_value->GetAsString(&out->type))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> UsbEvent::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  if (data.get())
    value->SetWithoutPathExpansion("data", this->data->DeepCopy());

  value->SetWithoutPathExpansion("srcId", Value::CreateIntegerValue(this->src_id));
  value->SetWithoutPathExpansion("isFinalEvent", Value::CreateBooleanValue(this->is_final_event));
  if (error.get())
    value->SetWithoutPathExpansion("error", Value::CreateStringValue(*this->error));

  if (result_code.get())
    value->SetWithoutPathExpansion("resultCode", Value::CreateIntegerValue(*this->result_code));

  value->SetWithoutPathExpansion("type", Value::CreateStringValue(this->type));

  return value.Pass();
}


GenericTransferInfo::GenericTransferInfo()
  : endpoint(0) {}
GenericTransferInfo::~GenericTransferInfo() {}

// static
bool GenericTransferInfo::Populate(const Value& value, GenericTransferInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* direction_value = NULL;
  if (!dict->GetWithoutPathExpansion("direction", &direction_value))
    return false;
  {
    if (!direction_value->GetAsString(&out->direction))
      return false;
  }

  Value* endpoint_value = NULL;
  if (!dict->GetWithoutPathExpansion("endpoint", &endpoint_value))
    return false;
  {
    if (!endpoint_value->GetAsInteger(&out->endpoint))
      return false;
  }

  Value* data_value = NULL;
  if (dict->GetWithoutPathExpansion("data", &data_value)) {
    {
      if (!data_value->IsType(Value::TYPE_BINARY))
        return false;
      out->data.reset(
          static_cast<BinaryValue*>(data_value)->DeepCopy());
    }
  }

  Value* length_value = NULL;
  if (dict->GetWithoutPathExpansion("length", &length_value)) {
    {
      int temp;
      if (!length_value->GetAsInteger(&temp))
        return false;
      out->length.reset(new int(temp));
    }
  }

  return true;
}

scoped_ptr<DictionaryValue> GenericTransferInfo::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("direction", Value::CreateStringValue(this->direction));
  value->SetWithoutPathExpansion("endpoint", Value::CreateIntegerValue(this->endpoint));
  if (data.get())
    value->SetWithoutPathExpansion("data", this->data->DeepCopy());

  if (length.get())
    value->SetWithoutPathExpansion("length", Value::CreateIntegerValue(*this->length));


  return value.Pass();
}


ControlTransferInfo::ControlTransferInfo()
  : index(0), request(0), value(0) {}
ControlTransferInfo::~ControlTransferInfo() {}

// static
bool ControlTransferInfo::Populate(const Value& value, ControlTransferInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* index_value = NULL;
  if (!dict->GetWithoutPathExpansion("index", &index_value))
    return false;
  {
    if (!index_value->GetAsInteger(&out->index))
      return false;
  }

  Value* direction_value = NULL;
  if (!dict->GetWithoutPathExpansion("direction", &direction_value))
    return false;
  {
    if (!direction_value->GetAsString(&out->direction))
      return false;
  }

  Value* request_type_value = NULL;
  if (!dict->GetWithoutPathExpansion("requestType", &request_type_value))
    return false;
  {
    if (!request_type_value->GetAsString(&out->request_type))
      return false;
  }

  Value* recipient_value = NULL;
  if (!dict->GetWithoutPathExpansion("recipient", &recipient_value))
    return false;
  {
    if (!recipient_value->GetAsString(&out->recipient))
      return false;
  }

  Value* request_value = NULL;
  if (!dict->GetWithoutPathExpansion("request", &request_value))
    return false;
  {
    if (!request_value->GetAsInteger(&out->request))
      return false;
  }

  Value* value_value = NULL;
  if (!dict->GetWithoutPathExpansion("value", &value_value))
    return false;
  {
    if (!value_value->GetAsInteger(&out->value))
      return false;
  }

  Value* length_value = NULL;
  if (dict->GetWithoutPathExpansion("length", &length_value)) {
    {
      int temp;
      if (!length_value->GetAsInteger(&temp))
        return false;
      out->length.reset(new int(temp));
    }
  }

  Value* data_value = NULL;
  if (dict->GetWithoutPathExpansion("data", &data_value)) {
    {
      if (!data_value->IsType(Value::TYPE_BINARY))
        return false;
      out->data.reset(
          static_cast<BinaryValue*>(data_value)->DeepCopy());
    }
  }

  return true;
}

scoped_ptr<DictionaryValue> ControlTransferInfo::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->SetWithoutPathExpansion("index", Value::CreateIntegerValue(this->index));
  value->SetWithoutPathExpansion("direction", Value::CreateStringValue(this->direction));
  value->SetWithoutPathExpansion("requestType", Value::CreateStringValue(this->request_type));
  value->SetWithoutPathExpansion("recipient", Value::CreateStringValue(this->recipient));
  value->SetWithoutPathExpansion("request", Value::CreateIntegerValue(this->request));
  value->SetWithoutPathExpansion("value", Value::CreateIntegerValue(this->value));
  if (length.get())
    value->SetWithoutPathExpansion("length", Value::CreateIntegerValue(*this->length));

  if (data.get())
    value->SetWithoutPathExpansion("data", this->data->DeepCopy());


  return value.Pass();
}


//
// Functions
//

IsochronousTransfer::Params::Params() {}
IsochronousTransfer::Params::~Params() {}

// static
scoped_ptr<IsochronousTransfer::Params> IsochronousTransfer::Params::Create(const ListValue& args) {
  if (args.GetSize() != 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* device_value = NULL;
  if (args.Get(0, &device_value) && !device_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!device_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!Device::Populate(*dictionary, &params->device))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* transfer_info_value = NULL;
  if (args.Get(1, &transfer_info_value) && !transfer_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!transfer_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!IsochronousTransferInfo::Populate(*dictionary, &params->transfer_info))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* IsochronousTransfer::Result::Create() {
  return Value::CreateNullValue();
}

CloseDevice::Params::Params() {}
CloseDevice::Params::~Params() {}

// static
scoped_ptr<CloseDevice::Params> CloseDevice::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* device_value = NULL;
  if (args.Get(0, &device_value) && !device_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!device_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!Device::Populate(*dictionary, &params->device))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}



FindDevice::Params::Params() {}
FindDevice::Params::~Params() {}

// static
scoped_ptr<FindDevice::Params> FindDevice::Params::Create(const ListValue& args) {
  if (args.GetSize() != 3)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* vendor_id_value = NULL;
  if (args.Get(0, &vendor_id_value) && !vendor_id_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!vendor_id_value->GetAsInteger(&params->vendor_id))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* product_id_value = NULL;
  if (args.Get(1, &product_id_value) && !product_id_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!product_id_value->GetAsInteger(&params->product_id))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* options_value = NULL;
  if (args.Get(2, &options_value) && !options_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!options_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!DeviceOptions::Populate(*dictionary, &params->options))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* FindDevice::Result::Create(const Device& device) {
  return device.ToValue().release();
}

BulkTransfer::Params::Params() {}
BulkTransfer::Params::~Params() {}

// static
scoped_ptr<BulkTransfer::Params> BulkTransfer::Params::Create(const ListValue& args) {
  if (args.GetSize() != 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* device_value = NULL;
  if (args.Get(0, &device_value) && !device_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!device_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!Device::Populate(*dictionary, &params->device))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* transfer_info_value = NULL;
  if (args.Get(1, &transfer_info_value) && !transfer_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!transfer_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!GenericTransferInfo::Populate(*dictionary, &params->transfer_info))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* BulkTransfer::Result::Create() {
  return Value::CreateNullValue();
}

InterruptTransfer::Params::Params() {}
InterruptTransfer::Params::~Params() {}

// static
scoped_ptr<InterruptTransfer::Params> InterruptTransfer::Params::Create(const ListValue& args) {
  if (args.GetSize() != 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* device_value = NULL;
  if (args.Get(0, &device_value) && !device_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!device_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!Device::Populate(*dictionary, &params->device))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* transfer_info_value = NULL;
  if (args.Get(1, &transfer_info_value) && !transfer_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!transfer_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!GenericTransferInfo::Populate(*dictionary, &params->transfer_info))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* InterruptTransfer::Result::Create() {
  return Value::CreateNullValue();
}

ControlTransfer::Params::Params() {}
ControlTransfer::Params::~Params() {}

// static
scoped_ptr<ControlTransfer::Params> ControlTransfer::Params::Create(const ListValue& args) {
  if (args.GetSize() != 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* device_value = NULL;
  if (args.Get(0, &device_value) && !device_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!device_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!Device::Populate(*dictionary, &params->device))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* transfer_info_value = NULL;
  if (args.Get(1, &transfer_info_value) && !transfer_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!transfer_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!ControlTransferInfo::Populate(*dictionary, &params->transfer_info))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* ControlTransfer::Result::Create() {
  return Value::CreateNullValue();
}

}  // experimental_usb
}  // api
}  // extensions
