// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/experimental_usb.idl
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_USB_H__
#define CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_USB_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace experimental_usb {
struct Device;
struct DeviceOptions;
struct IsochronousTransferInfo;
struct UsbEvent;
struct GenericTransferInfo;
struct ControlTransferInfo;
}  // experimental_usb

namespace experimental_usb {

//
// Types
//

struct Device {
  ~Device();
  Device();

  int vendor_id;

  int handle;

  int product_id;

  // Populates a Device object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, Device* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // Device object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(Device);
};

struct DeviceOptions {
  ~DeviceOptions();
  DeviceOptions();

  // Populates a DeviceOptions object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, DeviceOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // DeviceOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(DeviceOptions);
};

struct GenericTransferInfo {
  ~GenericTransferInfo();
  GenericTransferInfo();

  // The direction of this transfer. Must be one of in or out.
  std::string direction;

  int endpoint;

  // If this is an output transfer then this field must be populated. Otherwise,
  // it will be ignored.
  scoped_ptr<base::BinaryValue> data;

  // If this is an input transfer then this field indicates the size of the input
  // buffer. If this is an output transfer then this field is ignored.
  scoped_ptr<int> length;

  // Populates a GenericTransferInfo object from a Value. Returns whether |out|
  // was successfully populated.
  static bool Populate(const Value& value, GenericTransferInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // GenericTransferInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(GenericTransferInfo);
};

struct IsochronousTransferInfo {
  ~IsochronousTransferInfo();
  IsochronousTransferInfo();

  // The length of each of the packets in this transfer.
  int packet_length;

  // All of the normal transfer parameters are encapsulated in the transferInfo
  // parameters. Note that the data specified in this parameter block is split
  // along packetLength boundaries to form the individual packets of the
  // transfer.
  GenericTransferInfo transfer_info;

  // The total number of packets in this transfer.
  int packets;

  // Populates a IsochronousTransferInfo object from a Value. Returns whether
  // |out| was successfully populated.
  static bool Populate(const Value& value, IsochronousTransferInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // IsochronousTransferInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(IsochronousTransferInfo);
};

struct UsbEvent {
  ~UsbEvent();
  UsbEvent();

  // If the transfer was an input transfer then this field will contain all of
  // the input data requested.
  scoped_ptr<base::BinaryValue> data;

  int src_id;

  // The following fields are used for internal event routing and can be ignored.
  bool is_final_event;

  // If resultCode is not 0, this field will contain a textual description of the
  // error that occurred during the transfer.
  scoped_ptr<std::string> error;

  // A value of 0 indicates that the transfer was a success. Other values
  // indicate failure.
  scoped_ptr<int> result_code;

  // A string indicating the type of the event. Currently will only contain the
  // value 'transferResult'.
  std::string type;

  // Populates a UsbEvent object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, UsbEvent* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // UsbEvent object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(UsbEvent);
};

struct ControlTransferInfo {
  ~ControlTransferInfo();
  ControlTransferInfo();

  int index;

  // The direction of this transfer. Must be one of either in or out.
  std::string direction;

  // The type of this request. Must be one of standard, class, vendor, or
  // reserved.
  std::string request_type;

  // The intended recipient for this transfer. Must be one of device, interface,
  // endpoint, or other.
  std::string recipient;

  int request;

  int value;

  // If this transfer is an input transfer, then this field must be set to
  // indicate the expected data length. If this is an output transfer, then this
  // field is ignored.
  scoped_ptr<int> length;

  // The data payload carried by this transfer. If this is an output tranfer then
  // this field must be set.
  scoped_ptr<base::BinaryValue> data;

  // Populates a ControlTransferInfo object from a Value. Returns whether |out|
  // was successfully populated.
  static bool Populate(const Value& value, ControlTransferInfo* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ControlTransferInfo object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ControlTransferInfo);
};

//
// Functions
//

namespace IsochronousTransfer {
  struct Params {
    // An open device to make the transfer on.
    Device device;

    // The parameters to the transfer. See IsochronousTransferInfo.
    IsochronousTransferInfo transfer_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace CloseDevice {
  struct Params {
    // The device to close.
    Device device;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

};

namespace FindDevice {
  struct Params {
    // The vendor ID of the USB device to find.
    int vendor_id;

    // The product ID of the USB device to find.
    int product_id;

    DeviceOptions options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const Device& device);
  };

};

namespace BulkTransfer {
  struct Params {
    // An open device to make the transfer on.
    Device device;

    // The paramters to the transfer. See GenericTransferInfo.
    GenericTransferInfo transfer_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace InterruptTransfer {
  struct Params {
    // An open device to make the transfer on.
    Device device;

    // The paramters to the transfer. See GenericTransferInfo.
    GenericTransferInfo transfer_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace ControlTransfer {
  struct Params {
    // An open device to make the transfer on.
    Device device;

    // The parameters to the transfer. See ControlTransferInfo.
    ControlTransferInfo transfer_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

}  // experimental_usb
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_EXPERIMENTAL_USB_H__
