// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/file_system.idl
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_FILE_SYSTEM_H__
#define CHROME_COMMON_EXTENSIONS_API_FILE_SYSTEM_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace file_system {
struct ChooseFileOptions;
}  // file_system

namespace file_system {

//
// Types
//

struct ChooseFileOptions {
  ~ChooseFileOptions();
  ChooseFileOptions();

  // Valid types are 'openFile', 'openWritableFile' or 'saveFile'. Both
  // 'openFile' and 'openWritableFile' will prompt the user to open an existing
  // file, with 'openFile' returning a read-only FileEntry on success. 'saveFile'
  // will prompt the user to choose an existing file or a new file, and will
  // return a writable FileEntry. The default is 'openFile'.
  scoped_ptr<std::string> type;

  // Populates a ChooseFileOptions object from a Value. Returns whether |out|
  // was successfully populated.
  static bool Populate(const Value& value, ChooseFileOptions* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // ChooseFileOptions object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(ChooseFileOptions);
};

//
// Functions
//

namespace GetWritableFileEntry {
  struct Params {
    struct FileEntry {
      ~FileEntry();
      FileEntry();

      base::DictionaryValue additional_properties;

      // Populates a FileEntry object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, FileEntry* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(FileEntry);
    };

    FileEntry file_entry;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    struct FileEntry {
      ~FileEntry();
      FileEntry();

      base::DictionaryValue additional_properties;

      // Returns a new DictionaryValue representing the serialized form of this
      // FileEntry object. Passes ownership to caller.
      scoped_ptr<DictionaryValue> ToValue() const;

     private:
      DISALLOW_COPY_AND_ASSIGN(FileEntry);
    };

    Value* Create(const FileEntry& file_entry);
  };

};

namespace GetDisplayPath {
  struct Params {
    struct FileEntry {
      ~FileEntry();
      FileEntry();

      base::DictionaryValue additional_properties;

      // Populates a FileEntry object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, FileEntry* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(FileEntry);
    };

    FileEntry file_entry;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const std::string& display_path);
  };

};

namespace ChooseFile {
  struct Params {
    scoped_ptr<ChooseFileOptions> options;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    struct FileEntry {
      ~FileEntry();
      FileEntry();

      base::DictionaryValue additional_properties;

      // Returns a new DictionaryValue representing the serialized form of this
      // FileEntry object. Passes ownership to caller.
      scoped_ptr<DictionaryValue> ToValue() const;

     private:
      DISALLOW_COPY_AND_ASSIGN(FileEntry);
    };

    Value* Create(const FileEntry& file_entry);
  };

};

}  // file_system
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_FILE_SYSTEM_H__
