// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/common/extensions/api/generated_schemas.h"

namespace extensions {
namespace api {

// static
void GeneratedSchemas::Get(std::map<std::string, base::StringPiece>* schemas) {
  (*schemas)["alarms"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Creates an alarm.  Near the time(s) specified by <var>alarmInfo</var>, the <code>onAlarm</code> event is fired. If there is another alarm with the same name (or no name if none is specified), it will be cancelled and replaced by this alarm. Note that granularity is not guaranteed: times are more of a hint to the browser. For performance reasons, alarms may be delayed an arbitrary amount of time before firing.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"name\": \"name\", "
      "            \"description\": \"Optional name to identify this alarm. Defaults to the empty string.\""
      "          }, "
      "          {"
      "            \"description\": \"Describes when the alarm should fire.  The initial time must be specified by either <var>when</var> or <var>delayInMinutes</var> (but not both).  If <var>periodInMinutes</var> is set, the alarm will repeat every <var>periodInMinutes</var> minutes after the initial event.  If neither <var>when</var> or <var>delayInMinutes</var> is set for a repeating alarm, <var>periodInMinutes</var> is used as the default for <var>delayInMinutes</var>.\", "
      "            \"name\": \"alarmInfo\", "
      "            \"$ref\": \"alarms.AlarmCreateInfo\""
      "          }"
      "        ], "
      "        \"name\": \"create\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Retrieves details about the specified alarm.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"name\": \"name\", "
      "            \"description\": \"The name of the alarm to get. Defaults to the empty string.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"AlarmCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"alarm\", "
      "                \"$ref\": \"alarms.Alarm\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"get\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Gets an array of all the alarms.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"AlarmListCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"items\": {"
      "                  \"$ref\": \"alarms.Alarm\""
      "                }, "
      "                \"type\": \"array\", "
      "                \"name\": \"alarms\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"getAll\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Clears the alarm with the given name.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"name\": \"name\", "
      "            \"description\": \"The name of the alarm to clear. Defaults to the empty string.\""
      "          }"
      "        ], "
      "        \"name\": \"clear\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Clears all alarms.\", "
      "        \"parameters\": [], "
      "        \"name\": \"clearAll\""
      "      }"
      "    ], "
      "    \"namespace\": \"alarms\", "
      "    \"events\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Fired when an alarm has elapsed. Useful for transient background pages.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"The alarm that has elapsed.\", "
      "            \"name\": \"alarm\", "
      "            \"$ref\": \"alarms.Alarm\""
      "          }"
      "        ], "
      "        \"name\": \"onAlarm\""
      "      }"
      "    ], "
      "    \"types\": ["
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"alarms.Alarm\", "
      "        \"properties\": {"
      "          \"periodInMinutes\": {"
      "            \"type\": \"number\", "
      "            \"optional\": true, "
      "            \"description\": \"If not null, the alarm is a repeating alarm and will fire again in <var>periodInMinutes</var> minutes.\", "
      "            \"name\": \"periodInMinutes\""
      "          }, "
      "          \"scheduledTime\": {"
      "            \"type\": \"number\", "
      "            \"description\": \"Time at which this alarm was scheduled to fire, in milliseconds past the epoch (e.g. <code>Date.now() + n</code>).  For performance reasons, the alarm may have been delayed an arbitrary amount beyond this.\", "
      "            \"name\": \"scheduledTime\""
      "          }, "
      "          \"name\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"Name of this alarm.\", "
      "            \"name\": \"name\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"alarms.AlarmCreateInfo\", "
      "        \"properties\": {"
      "          \"delayInMinutes\": {"
      "            \"type\": \"number\", "
      "            \"optional\": true, "
      "            \"description\": \"Length of time in minutes after which the <code>onAlarm</code> event should fire. <!-- TODO: need minimum=0 -->\", "
      "            \"name\": \"delayInMinutes\""
      "          }, "
      "          \"periodInMinutes\": {"
      "            \"type\": \"number\", "
      "            \"optional\": true, "
      "            \"description\": \"If set, the onAlarm event should fire every <var>periodInMinutes</var> minutes after the initial event specified by <var>when</var> or <var>delayInMinutes</var>.  If not set, the alarm will only fire once. <!-- TODO: need minimum=0 -->\", "
      "            \"name\": \"periodInMinutes\""
      "          }, "
      "          \"when\": {"
      "            \"type\": \"number\", "
      "            \"optional\": true, "
      "            \"description\": \"Time at which the alarm should fire, in milliseconds past the epoch (e.g. <code>Date.now() + n</code>).\", "
      "            \"name\": \"when\""
      "          }"
      "        }"
      "      }"
      "    ]"
      "  }"
      "]";
  (*schemas)["appWindow"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"create\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"string\", "
      "            \"name\": \"url\""
      "          }, "
      "          {"
      "            \"optional\": true, "
      "            \"name\": \"options\", "
      "            \"$ref\": \"appWindow.CreateWindowOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"CreateWindowCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"integer\", "
      "                \"name\": \"view_id\""
      "              }"
      "            ]"
      "          }"
      "        ]"
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"focus\", "
      "        \"parameters\": []"
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"maximize\", "
      "        \"parameters\": []"
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"minimize\", "
      "        \"parameters\": []"
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"restore\", "
      "        \"parameters\": []"
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"nocompile\": true, "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"x\""
      "          }, "
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"y\""
      "          }"
      "        ], "
      "        \"name\": \"moveTo\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"nocompile\": true, "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"width\""
      "          }, "
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"height\""
      "          }"
      "        ], "
      "        \"name\": \"resizeTo\""
      "      }"
      "    ], "
      "    \"namespace\": \"appWindow\", "
      "    \"events\": [], "
      "    \"types\": ["
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"appWindow.CreateWindowOptions\", "
      "        \"properties\": {"
      "          \"maxWidth\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"Maximum width of the window.\", "
      "            \"name\": \"maxWidth\""
      "          }, "
      "          \"top\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"Y coordinate of the window.\", "
      "            \"name\": \"top\""
      "          }, "
      "          \"minHeight\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"Minimum height of the window.\", "
      "            \"name\": \"minHeight\""
      "          }, "
      "          \"maxHeight\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"Maximum height of the window.\", "
      "            \"name\": \"maxHeight\""
      "          }, "
      "          \"height\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"Height of the window.\", "
      "            \"name\": \"height\""
      "          }, "
      "          \"minWidth\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"Minimium width of the window.\", "
      "            \"name\": \"minWidth\""
      "          }, "
      "          \"width\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"Width of the window.\", "
      "            \"name\": \"width\""
      "          }, "
      "          \"type\": {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"description\": \"Window type: 'shell' (the default) is the only currently supported value.\", "
      "            \"name\": \"type\""
      "          }, "
      "          \"frame\": {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"description\": \"Frame type: 'none' or 'chrome' (defaults to 'chrome').\", "
      "            \"name\": \"frame\""
      "          }, "
      "          \"left\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"X coordinate of the window.\", "
      "            \"name\": \"left\""
      "          }"
      "        }"
      "      }"
      "    ]"
      "  }"
      "]";
  (*schemas)["experimental.bluetooth"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Checks if the system has bluetooth support.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"BooleanCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"boolean\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"isAvailable\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Checks if the system's bluetooth module has power.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"BooleanCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"boolean\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"isPowered\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Get the bluetooth address of the system's bluetooth module.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"AddressCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"string\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"getAddress\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Get a list of bluetooth devices. NOTE: This API is likely to change.  Please see crbug.com/134545\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"Controls which devices are returned.\", "
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.bluetooth.GetDevicesOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"DevicesCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"items\": {"
      "                  \"$ref\": \"experimental.bluetooth.Device\""
      "                }, "
      "                \"type\": \"array\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"getDevices\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Get a list of services provided by a device.\", "
      "        \"parameters\": ["
      "          {"
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.bluetooth.GetServicesOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"ServicesCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"items\": {"
      "                  \"$ref\": \"experimental.bluetooth.ServiceRecord\""
      "                }, "
      "                \"type\": \"array\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"getServices\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Connect to a service on a device.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"The options for the connection.\", "
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.bluetooth.ConnectOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"SocketCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"result\", "
      "                \"$ref\": \"experimental.bluetooth.Socket\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"connect\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Close a bluetooth connection.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"The options for this function.\", "
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.bluetooth.DisconnectOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"ResultCallback\", "
      "            \"parameters\": []"
      "          }"
      "        ], "
      "        \"name\": \"disconnect\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Read data from a bluetooth connection.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"The options for this function.\", "
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.bluetooth.ReadOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"DataCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"binary\", "
      "                \"name\": \"result\", "
      "                \"isInstanceOf\": \"ArrayBuffer\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"read\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Write data to a bluetooth connection.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"The options for this function.\", "
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.bluetooth.WriteOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"SizeCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"integer\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"write\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Get the local Out of Band Pairing data.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"OutOfBandPairingDataCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"data\", "
      "                \"$ref\": \"experimental.bluetooth.OutOfBandPairingData\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"getLocalOutOfBandPairingData\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Set the Out of Band Pairing data for a remote device. Any previous Out Of Band Pairing Data for this device is overwritten.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"The options for this function.\", "
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.bluetooth.SetOutOfBandPairingDataOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"ResultCallback\", "
      "            \"parameters\": []"
      "          }"
      "        ], "
      "        \"name\": \"setOutOfBandPairingData\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Start discovery. Discovered devices will be returned via the |onDeviceDiscovered| callback. Note that discovery can be resource intensive. stopDiscovery should be called as soon as is convenient.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"The options for this function.\", "
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.bluetooth.StartDiscoveryOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"ResultCallback\", "
      "            \"parameters\": []"
      "          }"
      "        ], "
      "        \"name\": \"startDiscovery\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Stop discovery.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"ResultCallback\", "
      "            \"parameters\": []"
      "          }"
      "        ], "
      "        \"name\": \"stopDiscovery\""
      "      }"
      "    ], "
      "    \"namespace\": \"experimental.bluetooth\", "
      "    \"events\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Fired when the availability of bluetooth on the system changes.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"boolean\", "
      "            \"name\": \"available\", "
      "            \"description\": \"True if bluetooth is available, false otherwise.\""
      "          }"
      "        ], "
      "        \"name\": \"onAvailabilityChanged\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Fired when the power state of bluetooth on the system changes.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"boolean\", "
      "            \"name\": \"has_power\""
      "          }"
      "        ], "
      "        \"name\": \"onPowerChanged\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Used to return discovered devices to the extension. Users should not add listeners to this event directly.\", "
      "        \"parameters\": ["
      "          {"
      "            \"name\": \"device\", "
      "            \"$ref\": \"experimental.bluetooth.Device\""
      "          }"
      "        ], "
      "        \"name\": \"onDeviceDiscovered_\""
      "      }"
      "    ], "
      "    \"types\": ["
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.Device\", "
      "        \"properties\": {"
      "          \"paired\": {"
      "            \"type\": \"boolean\", "
      "            \"description\": \"Indicates whether or not the device is paired with the system.\", "
      "            \"name\": \"paired\""
      "          }, "
      "          \"connected\": {"
      "            \"type\": \"boolean\", "
      "            \"description\": \"Indicates whether the device is currently connected to the system.\", "
      "            \"name\": \"connected\""
      "          }, "
      "          \"name\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The human-readable name of the device.\", "
      "            \"name\": \"name\""
      "          }, "
      "          \"bonded\": {"
      "            \"type\": \"boolean\", "
      "            \"description\": \"Indicates whether or not the device is bonded with the system. A device is bonded if it is paired and high-security link keys have been exchanged so that connections may be encrypted.\", "
      "            \"name\": \"bonded\""
      "          }, "
      "          \"address\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The address of the device, in the format 'XX:XX:XX:XX:XX:XX'.\", "
      "            \"name\": \"address\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.ServiceRecord\", "
      "        \"properties\": {"
      "          \"name\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The name of the service.\", "
      "            \"name\": \"name\""
      "          }, "
      "          \"uuid\": {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"description\": \"The UUID of the service.\", "
      "            \"name\": \"uuid\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.Socket\", "
      "        \"properties\": {"
      "          \"device\": {"
      "            \"name\": \"device\", "
      "            \"$ref\": \"experimental.bluetooth.Device\""
      "          }, "
      "          \"serviceUuid\": {"
      "            \"type\": \"string\", "
      "            \"name\": \"serviceUuid\""
      "          }, "
      "          \"id\": {"
      "            \"type\": \"integer\", "
      "            \"name\": \"id\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.OutOfBandPairingData\", "
      "        \"properties\": {"
      "          \"hash\": {"
      "            \"type\": \"binary\", "
      "            \"description\": \"Simple Pairing Hash C. Always 16 octets long.\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"name\": \"hash\""
      "          }, "
      "          \"randomizer\": {"
      "            \"type\": \"binary\", "
      "            \"description\": \"Simple Pairing Randomizer R. Always 16 octets long.\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"name\": \"randomizer\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.GetDevicesOptions\", "
      "        \"properties\": {"
      "          \"uuid\": {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"description\": \"Only devices providing a service with a UUID that matches |uuid| will be returned.\", "
      "            \"name\": \"uuid\""
      "          }, "
      "          \"name\": {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"description\": \"Only devices providing a service with a name that matches |name| will be returned.\", "
      "            \"name\": \"name\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.GetServicesOptions\", "
      "        \"properties\": {"
      "          \"deviceAddress\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The address of the device to inquire about. |deviceAddress| should be in the format 'XX:XX:XX:XX:XX:XX'.\", "
      "            \"name\": \"deviceAddress\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.ConnectOptions\", "
      "        \"properties\": {"
      "          \"serviceUuid\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The connection is made to the service with UUID |serviceUuid|.\", "
      "            \"name\": \"serviceUuid\""
      "          }, "
      "          \"deviceAddress\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The connection is made to the device at |deviceAddress|. |deviceAddress| should be in the format 'XX:XX:XX:XX:XX:XX'.\", "
      "            \"name\": \"deviceAddress\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.DisconnectOptions\", "
      "        \"properties\": {"
      "          \"socketId\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The socket to disconnect.\", "
      "            \"name\": \"socketId\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.ReadOptions\", "
      "        \"properties\": {"
      "          \"socketId\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The socket to read from.\", "
      "            \"name\": \"socketId\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.WriteOptions\", "
      "        \"properties\": {"
      "          \"data\": {"
      "            \"type\": \"binary\", "
      "            \"description\": \"The data to write.\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"name\": \"data\""
      "          }, "
      "          \"socketId\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The socket to write to.\", "
      "            \"name\": \"socketId\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.SetOutOfBandPairingDataOptions\", "
      "        \"properties\": {"
      "          \"data\": {"
      "            \"$ref\": \"experimental.bluetooth.OutOfBandPairingData\", "
      "            \"optional\": true, "
      "            \"description\": \"The Out Of Band Pairing Data. If this is omitted, the data for the device is cleared instead.\", "
      "            \"name\": \"data\""
      "          }, "
      "          \"address\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The address of the remote device that the data should be associated with. |deviceAddress| should be in the format 'XX:XX:XX:XX:XX:XX'.\", "
      "            \"name\": \"address\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.bluetooth.StartDiscoveryOptions\", "
      "        \"properties\": {"
      "          \"deviceCallback\": {"
      "            \"type\": \"function\", "
      "            \"description\": \"Called for each device that is discovered.\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"device\", "
      "                \"$ref\": \"experimental.bluetooth.Device\""
      "              }"
      "            ], "
      "            \"name\": \"DeviceCallback\""
      "          }"
      "        }"
      "      }"
      "    ]"
      "  }"
      "]";
  (*schemas)["experimental.discovery"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Suggests a URL for discovery.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"Detailed information on the URL to suggest.\", "
      "            \"name\": \"details\", "
      "            \"$ref\": \"experimental.discovery.SuggestDetails\""
      "          }"
      "        ], "
      "        \"name\": \"suggest\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Removes a URL that was previously suggested for discovery by this extension.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"string\", "
      "            \"name\": \"linkUrl\", "
      "            \"description\": \"The URl to remove from discovery. Must be exactly the same as a linkUrl previously used on a call to suggest.\""
      "          }"
      "        ], "
      "        \"name\": \"removeSuggestion\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Clear all the URLs that were previously suggested for discovery by this extension.\", "
      "        \"parameters\": [], "
      "        \"name\": \"clearAllSuggestions\""
      "      }"
      "    ], "
      "    \"namespace\": \"experimental.discovery\", "
      "    \"events\": [], "
      "    \"types\": ["
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.discovery.SuggestDetails\", "
      "        \"properties\": {"
      "          \"score\": {"
      "            \"type\": \"number\", "
      "            \"optional\": true, "
      "            \"description\": \"A score indicating how interesting that suggestion is. The value must be between 0 and 1. A suggestion with score 1 is twice as likely to be displayed than one with a score of 0.5. Defaults to 1. TODO: need minimum=0 and maximum=1.\", "
      "            \"name\": \"score\""
      "          }, "
      "          \"linkUrl\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The URL to suggest and that will be displayed in the new tab page under the recommended pane.\", "
      "            \"name\": \"linkUrl\""
      "          }, "
      "          \"linkText\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The linkified text. It should be relatively short.\", "
      "            \"name\": \"linkText\""
      "          }"
      "        }"
      "      }"
      "    ]"
      "  }"
      "]";
  (*schemas)["experimental.dns"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Resolves the given hostname or IP address literal.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"string\", "
      "            \"name\": \"hostname\", "
      "            \"description\": \"The hostname to resolve.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"ResolveCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"resolveInfo\", "
      "                \"$ref\": \"experimental.dns.ResolveCallbackResolveInfo\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"resolve\""
      "      }"
      "    ], "
      "    \"namespace\": \"experimental.dns\", "
      "    \"events\": [], "
      "    \"types\": ["
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.dns.ResolveCallbackResolveInfo\", "
      "        \"properties\": {"
      "          \"resultCode\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The result code. Zero indicates success.\", "
      "            \"name\": \"resultCode\""
      "          }, "
      "          \"address\": {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"description\": \"A string representing the IP address literal. Supplied only if resultCode indicates success. Note that we presently return only IPv4 addresses.\", "
      "            \"name\": \"address\""
      "          }"
      "        }"
      "      }"
      "    ]"
      "  }"
      "]";
  (*schemas)["experimental.idltest"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Functions for testing binary data request/response parameters. The first two just return back the bytes they were passed in an array.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"binary\", "
      "            \"name\": \"input\", "
      "            \"isInstanceOf\": \"ArrayBuffer\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"LongArrayCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"items\": {"
      "                  \"type\": \"integer\""
      "                }, "
      "                \"type\": \"array\", "
      "                \"name\": \"array\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"sendArrayBuffer\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"TODO(asargent) - we currently can't have [instanceOf=ArrayBufferView], I think because ArrayBufferView isn't an instantiable type. The best we might be able to do is have a 'choices' list including all the typed array subclasses like Uint8Array, Uint16Array, Float32Array, etc.\", "
      "        \"parameters\": ["
      "          {"
      "            \"additionalProperties\": {"
      "              \"type\": \"any\""
      "            }, "
      "            \"type\": \"object\", "
      "            \"name\": \"input\", "
      "            \"isInstanceOf\": \"Uint8Array\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"LongArrayCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"items\": {"
      "                  \"type\": \"integer\""
      "                }, "
      "                \"type\": \"array\", "
      "                \"name\": \"array\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"sendArrayBufferView\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"getArrayBuffer\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"ArrayBufferCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"binary\", "
      "                \"name\": \"buffer\", "
      "                \"isInstanceOf\": \"ArrayBuffer\""
      "              }"
      "            ]"
      "          }"
      "        ]"
      "      }, "
      "      {"
      "        \"name\": \"nocompileFunc\", "
      "        \"type\": \"function\", "
      "        \"nocompile\": true, "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"switch\""
      "          }"
      "        ], "
      "        \"description\": \"This function should not have C++ code autogenerated (the variable name |switch| should cause compile errors if it does). But the name should get defined and made visible from within extensions/apps code.\""
      "      }"
      "    ], "
      "    \"namespace\": \"experimental.idltest\", "
      "    \"events\": [], "
      "    \"types\": []"
      "  }"
      "]";
  (*schemas)["experimental.serial"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Returns names of valid ports on this machine, each of which is likely to be valid to pass as the port argument to open(). The list is regenerated each time this method is called, as port validity is dynamic.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"GetPortsCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"items\": {"
      "                  \"type\": \"string\""
      "                }, "
      "                \"type\": \"array\", "
      "                \"name\": \"ports\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"getPorts\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Opens a connection to the given serial port.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"string\", "
      "            \"name\": \"port\", "
      "            \"description\": \"The name of the serial port to open.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"OpenCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"openInfo\", "
      "                \"$ref\": \"experimental.serial.OpenInfo\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"open\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Closes an open connection.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"connectionId\", "
      "            \"description\": \"The id of the opened connection.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"CloseCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"boolean\", "
      "                \"name\": \"result\""
      "              }"
      "            ], "
      "            \"description\": \"Returns true if operation was successful.\""
      "          }"
      "        ], "
      "        \"name\": \"close\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Reads a byte from the given connection.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"connectionId\", "
      "            \"description\": \"The id of the connection.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"ReadCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"readInfo\", "
      "                \"$ref\": \"experimental.serial.ReadInfo\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"read\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Writes a string to the given connection.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"connectionId\", "
      "            \"description\": \"The id of the connection.\""
      "          }, "
      "          {"
      "            \"type\": \"binary\", "
      "            \"name\": \"data\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"description\": \"The string to write.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"WriteCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"writeInfo\", "
      "                \"$ref\": \"experimental.serial.WriteInfo\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"write\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Flushes all bytes in the given connection's input and output buffers.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"connectionId\", "
      "            \"description\": \"The id of the connection.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"FlushCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"boolean\", "
      "                \"name\": \"result\""
      "              }"
      "            ], "
      "            \"description\": \"Returns true if operation was successful.\""
      "          }"
      "        ], "
      "        \"name\": \"flush\""
      "      }"
      "    ], "
      "    \"namespace\": \"experimental.serial\", "
      "    \"events\": [], "
      "    \"types\": ["
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.serial.OpenInfo\", "
      "        \"properties\": {"
      "          \"connectionId\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The id of the opened connection.\", "
      "            \"name\": \"connectionId\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.serial.ReadInfo\", "
      "        \"properties\": {"
      "          \"data\": {"
      "            \"type\": \"binary\", "
      "            \"description\": \"The data received.\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"name\": \"data\""
      "          }, "
      "          \"bytesRead\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The number of bytes received, or a negative number if an error occurred.\", "
      "            \"name\": \"bytesRead\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.serial.WriteInfo\", "
      "        \"properties\": {"
      "          \"bytesWritten\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The number of bytes written.\", "
      "            \"name\": \"bytesWritten\""
      "          }"
      "        }"
      "      }"
      "    ]"
      "  }"
      "]";
  (*schemas)["experimental.socket"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Creates a socket of the specified type that will connect to the specified remote machine.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"The type of socket to create. Must be <code>tcp</code> or <code>udp</code>.\", "
      "            \"name\": \"type\", "
      "            \"$ref\": \"experimental.socket.SocketType\""
      "          }, "
      "          {"
      "            \"description\": \"The socket options.\", "
      "            \"optional\": true, "
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.socket.CreateOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"CreateCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"createInfo\", "
      "                \"$ref\": \"experimental.socket.CreateInfo\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"create\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Destroys the socket. Each socket created should be destroyed after use.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }"
      "        ], "
      "        \"name\": \"destroy\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Connects the socket to the remote machine.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }, "
      "          {"
      "            \"type\": \"string\", "
      "            \"name\": \"hostname\", "
      "            \"description\": \"The hostname or IP address of the remote machine.\""
      "          }, "
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"port\", "
      "            \"description\": \"The port of the remote machine.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"ConnectCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"integer\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"connect\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Binds the local address for socket. Currently, it does not support TCP socket.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }, "
      "          {"
      "            \"type\": \"string\", "
      "            \"name\": \"address\", "
      "            \"description\": \"The address of the local machine.\""
      "          }, "
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"port\", "
      "            \"description\": \"The port of the local machine.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"BindCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"integer\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"bind\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Disconnects the socket. For UDP sockets, <code>disconnect</code> is a non-operation but is safe to call.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }"
      "        ], "
      "        \"name\": \"disconnect\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Reads data from the given socket.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }, "
      "          {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"name\": \"bufferSize\", "
      "            \"description\": \"The read buffer size.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"ReadCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"readInfo\", "
      "                \"$ref\": \"experimental.socket.ReadInfo\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"read\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Writes data on the given socket.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }, "
      "          {"
      "            \"type\": \"binary\", "
      "            \"name\": \"data\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"description\": \"The data to write.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"WriteCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"writeInfo\", "
      "                \"$ref\": \"experimental.socket.WriteInfo\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"write\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Reads data from the given socket.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }, "
      "          {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"name\": \"bufferSize\", "
      "            \"description\": \"The receive buffer size.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"RecvFromCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"recvFromInfo\", "
      "                \"$ref\": \"experimental.socket.RecvFromInfo\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"recvFrom\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Writes data on the given socket.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }, "
      "          {"
      "            \"type\": \"binary\", "
      "            \"name\": \"data\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"description\": \"The data to write.\""
      "          }, "
      "          {"
      "            \"type\": \"string\", "
      "            \"name\": \"address\", "
      "            \"description\": \"The address of the remote machine.\""
      "          }, "
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"port\", "
      "            \"description\": \"The port of the remote machine.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"SendToCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"writeInfo\", "
      "                \"$ref\": \"experimental.socket.WriteInfo\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"sendTo\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Enable/disable keep-alive functionality for a TCP connection.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }, "
      "          {"
      "            \"type\": \"boolean\", "
      "            \"name\": \"enable\", "
      "            \"description\": \"If true, enable keep-alive functionality.\""
      "          }, "
      "          {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"name\": \"delay\", "
      "            \"description\": \"Set the delay seconds between the last data packet received and the first keepalive probe. Default is 0.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"SetKeepAliveCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"boolean\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"setKeepAlive\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Enable/disable Nagle algorithm.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"socketId\", "
      "            \"description\": \"The socketId.\""
      "          }, "
      "          {"
      "            \"type\": \"boolean\", "
      "            \"name\": \"noDelay\", "
      "            \"description\": \"If true, disable Nagle algorithm.\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"SetNoDelayCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"boolean\", "
      "                \"name\": \"result\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"setNoDelay\""
      "      }"
      "    ], "
      "    \"namespace\": \"experimental.socket\", "
      "    \"events\": [], "
      "    \"types\": ["
      "      {"
      "        \"enum\": ["
      "          \"tcp\", "
      "          \"udp\""
      "        ], "
      "        \"type\": \"string\", "
      "        \"id\": \"experimental.socket.SocketType\""
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.socket.CreateOptions\", "
      "        \"properties\": {"
      "          \"dummyValue\": {"
      "            \"nodoc\": true, "
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"The schema generator does not support dictionaries without any fields. Ignore this field.\", "
      "            \"name\": \"dummyValue\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.socket.CreateInfo\", "
      "        \"properties\": {"
      "          \"socketId\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The id of the newly created socket.\", "
      "            \"name\": \"socketId\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.socket.ReadInfo\", "
      "        \"properties\": {"
      "          \"resultCode\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The resultCode returned from the underlying read() call.\", "
      "            \"name\": \"resultCode\""
      "          }, "
      "          \"data\": {"
      "            \"type\": \"binary\", "
      "            \"name\": \"data\", "
      "            \"isInstanceOf\": \"ArrayBuffer\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.socket.WriteInfo\", "
      "        \"properties\": {"
      "          \"bytesWritten\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The number of bytes sent, or a negative error code.\", "
      "            \"name\": \"bytesWritten\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.socket.RecvFromInfo\", "
      "        \"properties\": {"
      "          \"resultCode\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The resultCode returned from the underlying read() call.\", "
      "            \"name\": \"resultCode\""
      "          }, "
      "          \"data\": {"
      "            \"type\": \"binary\", "
      "            \"name\": \"data\", "
      "            \"isInstanceOf\": \"ArrayBuffer\""
      "          }, "
      "          \"port\": {"
      "            \"type\": \"integer\", "
      "            \"name\": \"port\""
      "          }, "
      "          \"address\": {"
      "            \"type\": \"string\", "
      "            \"name\": \"address\""
      "          }"
      "        }"
      "      }"
      "    ]"
      "  }"
      "]";
  (*schemas)["experimental.usb"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Finds the first instance of the USB device specified by the vendorId/ productId pair and, if permissions allow, opens it for use. Upon successfully opening a device the callback is invoked with a populated Device object. On failure, the callback is invoked with null.\", "
      "        \"parameters\": ["
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"vendorId\", "
      "            \"description\": \"The vendor ID of the USB device to find.\""
      "          }, "
      "          {"
      "            \"type\": \"integer\", "
      "            \"name\": \"productId\", "
      "            \"description\": \"The product ID of the USB device to find.\""
      "          }, "
      "          {"
      "            \"name\": \"options\", "
      "            \"$ref\": \"experimental.usb.DeviceOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"FindDeviceCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"optional\": true, "
      "                \"name\": \"device\", "
      "                \"$ref\": \"experimental.usb.Device\""
      "              }"
      "            ]"
      "          }"
      "        ], "
      "        \"name\": \"findDevice\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Closes an open device instance. Invoking operations on a device after it has been closed is a safe operation, but causes no action to be taken.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"The device to close.\", "
      "            \"name\": \"device\", "
      "            \"$ref\": \"experimental.usb.Device\""
      "          }"
      "        ], "
      "        \"name\": \"closeDevice\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Performs a control transfer on the specified device. See the ControlTransferInfo structure for the parameters required to make a transfer.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"An open device to make the transfer on.\", "
      "            \"name\": \"device\", "
      "            \"$ref\": \"experimental.usb.Device\""
      "          }, "
      "          {"
      "            \"description\": \"The parameters to the transfer. See ControlTransferInfo.\", "
      "            \"name\": \"transferInfo\", "
      "            \"$ref\": \"experimental.usb.ControlTransferInfo\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"TransferCallback\", "
      "            \"parameters\": []"
      "          }"
      "        ], "
      "        \"name\": \"controlTransfer\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Performs a bulk transfer on the specified device.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"An open device to make the transfer on.\", "
      "            \"name\": \"device\", "
      "            \"$ref\": \"experimental.usb.Device\""
      "          }, "
      "          {"
      "            \"description\": \"The paramters to the transfer. See GenericTransferInfo.\", "
      "            \"name\": \"transferInfo\", "
      "            \"$ref\": \"experimental.usb.GenericTransferInfo\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"TransferCallback\", "
      "            \"parameters\": []"
      "          }"
      "        ], "
      "        \"name\": \"bulkTransfer\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Performs an interrupt transfer on the specified device.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"An open device to make the transfer on.\", "
      "            \"name\": \"device\", "
      "            \"$ref\": \"experimental.usb.Device\""
      "          }, "
      "          {"
      "            \"description\": \"The paramters to the transfer. See GenericTransferInfo.\", "
      "            \"name\": \"transferInfo\", "
      "            \"$ref\": \"experimental.usb.GenericTransferInfo\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"TransferCallback\", "
      "            \"parameters\": []"
      "          }"
      "        ], "
      "        \"name\": \"interruptTransfer\""
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"description\": \"Performs an isochronous transfer on the specific device.\", "
      "        \"parameters\": ["
      "          {"
      "            \"description\": \"An open device to make the transfer on.\", "
      "            \"name\": \"device\", "
      "            \"$ref\": \"experimental.usb.Device\""
      "          }, "
      "          {"
      "            \"description\": \"The parameters to the transfer. See IsochronousTransferInfo.\", "
      "            \"name\": \"transferInfo\", "
      "            \"$ref\": \"experimental.usb.IsochronousTransferInfo\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"TransferCallback\", "
      "            \"parameters\": []"
      "          }"
      "        ], "
      "        \"name\": \"isochronousTransfer\""
      "      }"
      "    ], "
      "    \"namespace\": \"experimental.usb\", "
      "    \"events\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"onEvent\", "
      "        \"parameters\": ["
      "          {"
      "            \"name\": \"event\", "
      "            \"$ref\": \"experimental.usb.UsbEvent\""
      "          }"
      "        ]"
      "      }"
      "    ], "
      "    \"types\": ["
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.usb.Device\", "
      "        \"properties\": {"
      "          \"vendorId\": {"
      "            \"type\": \"integer\", "
      "            \"name\": \"vendorId\""
      "          }, "
      "          \"handle\": {"
      "            \"type\": \"integer\", "
      "            \"name\": \"handle\""
      "          }, "
      "          \"productId\": {"
      "            \"type\": \"integer\", "
      "            \"name\": \"productId\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.usb.ControlTransferInfo\", "
      "        \"properties\": {"
      "          \"index\": {"
      "            \"type\": \"integer\", "
      "            \"name\": \"index\""
      "          }, "
      "          \"direction\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The direction of this transfer. Must be one of either in or out.\", "
      "            \"name\": \"direction\""
      "          }, "
      "          \"requestType\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The type of this request. Must be one of standard, class, vendor, or reserved.\", "
      "            \"name\": \"requestType\""
      "          }, "
      "          \"data\": {"
      "            \"type\": \"binary\", "
      "            \"optional\": true, "
      "            \"description\": \"The data payload carried by this transfer. If this is an output tranfer then this field must be set.\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"name\": \"data\""
      "          }, "
      "          \"request\": {"
      "            \"type\": \"integer\", "
      "            \"name\": \"request\""
      "          }, "
      "          \"value\": {"
      "            \"type\": \"integer\", "
      "            \"name\": \"value\""
      "          }, "
      "          \"length\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"If this transfer is an input transfer, then this field must be set to indicate the expected data length. If this is an output transfer, then this field is ignored.\", "
      "            \"name\": \"length\""
      "          }, "
      "          \"recipient\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The intended recipient for this transfer. Must be one of device, interface, endpoint, or other.\", "
      "            \"name\": \"recipient\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.usb.GenericTransferInfo\", "
      "        \"properties\": {"
      "          \"direction\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"The direction of this transfer. Must be one of in or out.\", "
      "            \"name\": \"direction\""
      "          }, "
      "          \"endpoint\": {"
      "            \"type\": \"integer\", "
      "            \"name\": \"endpoint\""
      "          }, "
      "          \"data\": {"
      "            \"type\": \"binary\", "
      "            \"optional\": true, "
      "            \"description\": \"If this is an output transfer then this field must be populated. Otherwise, it will be ignored.\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"name\": \"data\""
      "          }, "
      "          \"length\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"If this is an input transfer then this field indicates the size of the input buffer. If this is an output transfer then this field is ignored.\", "
      "            \"name\": \"length\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.usb.IsochronousTransferInfo\", "
      "        \"properties\": {"
      "          \"packetLength\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The length of each of the packets in this transfer.\", "
      "            \"name\": \"packetLength\""
      "          }, "
      "          \"transferInfo\": {"
      "            \"$ref\": \"experimental.usb.GenericTransferInfo\", "
      "            \"description\": \"All of the normal transfer parameters are encapsulated in the transferInfo parameters. Note that the data specified in this parameter block is split along packetLength boundaries to form the individual packets of the transfer.\", "
      "            \"name\": \"transferInfo\""
      "          }, "
      "          \"packets\": {"
      "            \"type\": \"integer\", "
      "            \"description\": \"The total number of packets in this transfer.\", "
      "            \"name\": \"packets\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.usb.UsbEvent\", "
      "        \"properties\": {"
      "          \"type\": {"
      "            \"type\": \"string\", "
      "            \"description\": \"A string indicating the type of the event. Currently will only contain the value 'transferResult'.\", "
      "            \"name\": \"type\""
      "          }, "
      "          \"srcId\": {"
      "            \"type\": \"integer\", "
      "            \"nodoc\": true, "
      "            \"name\": \"srcId\""
      "          }, "
      "          \"isFinalEvent\": {"
      "            \"type\": \"boolean\", "
      "            \"nodoc\": true, "
      "            \"description\": \"The following fields are used for internal event routing and can be ignored.\", "
      "            \"name\": \"isFinalEvent\""
      "          }, "
      "          \"error\": {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"description\": \"If resultCode is not 0, this field will contain a textual description of the error that occurred during the transfer.\", "
      "            \"name\": \"error\""
      "          }, "
      "          \"resultCode\": {"
      "            \"type\": \"integer\", "
      "            \"optional\": true, "
      "            \"description\": \"A value of 0 indicates that the transfer was a success. Other values indicate failure.\", "
      "            \"name\": \"resultCode\""
      "          }, "
      "          \"data\": {"
      "            \"type\": \"binary\", "
      "            \"optional\": true, "
      "            \"description\": \"If the transfer was an input transfer then this field will contain all of the input data requested.\", "
      "            \"isInstanceOf\": \"ArrayBuffer\", "
      "            \"name\": \"data\""
      "          }"
      "        }"
      "      }, "
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"experimental.usb.DeviceOptions\", "
      "        \"properties\": {"
      "          \"onEvent\": {"
      "            \"description\": \"Invoked by the extension API whenever an event occurs for the device(s) that this DeviceOptions is associated with.\", "
      "            \"parameters\": ["
      "              {"
      "                \"name\": \"event\", "
      "                \"$ref\": \"experimental.usb.UsbEvent\""
      "              }"
      "            ], "
      "            \"type\": \"function\", "
      "            \"optional\": true, "
      "            \"name\": \"OnEventCallback\""
      "          }"
      "        }"
      "      }"
      "    ]"
      "  }"
      "]";
  (*schemas)["fileSystem"] =
      "["
      "  {"
      "    \"nodoc\": false, "
      "    \"functions\": ["
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"getDisplayPath\", "
      "        \"parameters\": ["
      "          {"
      "            \"additionalProperties\": {"
      "              \"type\": \"any\""
      "            }, "
      "            \"type\": \"object\", "
      "            \"name\": \"fileEntry\", "
      "            \"isInstanceOf\": \"FileEntry\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"GetDisplayPathCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"type\": \"string\", "
      "                \"name\": \"displayPath\""
      "              }"
      "            ]"
      "          }"
      "        ]"
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"getWritableFileEntry\", "
      "        \"parameters\": ["
      "          {"
      "            \"additionalProperties\": {"
      "              \"type\": \"any\""
      "            }, "
      "            \"type\": \"object\", "
      "            \"name\": \"fileEntry\", "
      "            \"isInstanceOf\": \"FileEntry\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"FileEntryCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"additionalProperties\": {"
      "                  \"type\": \"any\""
      "                }, "
      "                \"type\": \"object\", "
      "                \"name\": \"fileEntry\", "
      "                \"isInstanceOf\": \"fileEntry\""
      "              }"
      "            ]"
      "          }"
      "        ]"
      "      }, "
      "      {"
      "        \"type\": \"function\", "
      "        \"name\": \"chooseFile\", "
      "        \"parameters\": ["
      "          {"
      "            \"optional\": true, "
      "            \"name\": \"options\", "
      "            \"$ref\": \"fileSystem.ChooseFileOptions\""
      "          }, "
      "          {"
      "            \"type\": \"function\", "
      "            \"name\": \"FileEntryCallback\", "
      "            \"parameters\": ["
      "              {"
      "                \"additionalProperties\": {"
      "                  \"type\": \"any\""
      "                }, "
      "                \"type\": \"object\", "
      "                \"name\": \"fileEntry\", "
      "                \"isInstanceOf\": \"fileEntry\""
      "              }"
      "            ]"
      "          }"
      "        ]"
      "      }"
      "    ], "
      "    \"namespace\": \"fileSystem\", "
      "    \"events\": [], "
      "    \"types\": ["
      "      {"
      "        \"type\": \"object\", "
      "        \"id\": \"fileSystem.ChooseFileOptions\", "
      "        \"properties\": {"
      "          \"type\": {"
      "            \"type\": \"string\", "
      "            \"optional\": true, "
      "            \"description\": \"Valid types are 'openFile', 'openWritableFile' or 'saveFile'. Both 'openFile' and 'openWritableFile' will prompt the user to open an existing file, with 'openFile' returning a read-only FileEntry on success. 'saveFile' will prompt the user to choose an existing file or a new file, and will return a writable FileEntry. The default is 'openFile'.\", "
      "            \"name\": \"type\""
      "          }"
      "        }"
      "      }"
      "    ]"
      "  }"
      "]";
}

}  // api
}  // extensions
