// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/storage.json
// DO NOT EDIT.

#include "tools/json_schema_compiler/util.h"
#include "chrome/common/extensions/api/storage.h"

using base::Value;
using base::DictionaryValue;
using base::ListValue;
using base::BinaryValue;
using json_schema_compiler::any::Any;

namespace extensions {
namespace api {
namespace storage {

//
// Properties
//

namespace local {
  const int QUOTA_BYTES = 5242880;
}  // namespace local

namespace sync {
  const int MAX_ITEMS = 512;
  const int QUOTA_BYTES_PER_ITEM = 2048;
  const int MAX_WRITE_OPERATIONS_PER_HOUR = 1000;
  const int MAX_SUSTAINED_WRITE_OPERATIONS_PER_MINUTE = 10;
  const int QUOTA_BYTES = 102400;
}  // namespace sync

//
// Types
//

StorageArea::GetBytesInUse::Params::Params() {}
StorageArea::GetBytesInUse::Params::~Params() {}

// static
scoped_ptr<StorageArea::GetBytesInUse::Params> StorageArea::GetBytesInUse::Params::Create(const ListValue& args) {
  if (args.GetSize() > 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());
  params->keys_type = KEYS_NONE;

  Value* keys_value = NULL;
  if (args.Get(0, &keys_value) && !keys_value->IsType(Value::TYPE_NULL))
  {
    {
      switch (keys_value->GetType()) {
        case Value::TYPE_STRING: {
          {
            std::string temp;
            if (!keys_value->GetAsString(&temp))
              return scoped_ptr<Params>();
            params->keys_string.reset(new std::string(temp));
          }
          params->keys_type = KEYS_STRING;
          break;
        }
        case Value::TYPE_LIST: {
          {
            ListValue* list = NULL;
            if (!keys_value->GetAsList(&list))
              return scoped_ptr<Params>();
            if (!json_schema_compiler::util::PopulateOptionalArrayFromList(*list, &params->keys_array))
              return scoped_ptr<Params>();
          }
          params->keys_type = KEYS_ARRAY;
          break;
        }
        default:
          return scoped_ptr<Params>();
      }
    }
  }

  return params.Pass();
}


Value* StorageArea::GetBytesInUse::Result::Create(const int bytes_in_use) {
  return Value::CreateIntegerValue(bytes_in_use);
}

Value* StorageArea::Clear::Result::Create() {
  return Value::CreateNullValue();
}

StorageArea::Set::Params::Items::Items()
   {}
StorageArea::Set::Params::Items::~Items() {}

// static
bool StorageArea::Set::Params::Items::Populate(const Value& value, Items* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  out->additional_properties.MergeDictionary(dict);

  return true;
}


StorageArea::Set::Params::Params() {}
StorageArea::Set::Params::~Params() {}

// static
scoped_ptr<StorageArea::Set::Params> StorageArea::Set::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* items_value = NULL;
  if (args.Get(0, &items_value) && !items_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!items_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!Items::Populate(*dictionary, &params->items))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* StorageArea::Set::Result::Create() {
  return Value::CreateNullValue();
}

StorageArea::Remove::Params::Params() {}
StorageArea::Remove::Params::~Params() {}

// static
scoped_ptr<StorageArea::Remove::Params> StorageArea::Remove::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* keys_value = NULL;
  if (args.Get(0, &keys_value) && !keys_value->IsType(Value::TYPE_NULL))
  {
    {
      switch (keys_value->GetType()) {
        case Value::TYPE_STRING: {
          {
            std::string temp;
            if (!keys_value->GetAsString(&temp))
              return scoped_ptr<Params>();
            params->keys_string.reset(new std::string(temp));
          }
          params->keys_type = KEYS_STRING;
          break;
        }
        case Value::TYPE_LIST: {
          {
            ListValue* list = NULL;
            if (!keys_value->GetAsList(&list))
              return scoped_ptr<Params>();
            if (!json_schema_compiler::util::PopulateOptionalArrayFromList(*list, &params->keys_array))
              return scoped_ptr<Params>();
          }
          params->keys_type = KEYS_ARRAY;
          break;
        }
        default:
          return scoped_ptr<Params>();
      }
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* StorageArea::Remove::Result::Create() {
  return Value::CreateNullValue();
}

StorageArea::Get::Params::Keys::Keys()
   {}
StorageArea::Get::Params::Keys::~Keys() {}

// static
bool StorageArea::Get::Params::Keys::Populate(const Value& value, Keys* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  out->additional_properties.MergeDictionary(dict);

  return true;
}


StorageArea::Get::Params::Params() {}
StorageArea::Get::Params::~Params() {}

// static
scoped_ptr<StorageArea::Get::Params> StorageArea::Get::Params::Create(const ListValue& args) {
  if (args.GetSize() > 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());
  params->keys_type = KEYS_NONE;

  Value* keys_value = NULL;
  if (args.Get(0, &keys_value) && !keys_value->IsType(Value::TYPE_NULL))
  {
    {
      switch (keys_value->GetType()) {
        case Value::TYPE_STRING: {
          {
            std::string temp;
            if (!keys_value->GetAsString(&temp))
              return scoped_ptr<Params>();
            params->keys_string.reset(new std::string(temp));
          }
          params->keys_type = KEYS_STRING;
          break;
        }
        case Value::TYPE_DICTIONARY: {
          {
            DictionaryValue* dictionary = NULL;
            if (!keys_value->GetAsDictionary(&dictionary))
              return scoped_ptr<Params>();
            scoped_ptr<Keys> temp(new Keys());
            if (!Keys::Populate(*dictionary, temp.get()))
              return scoped_ptr<Params>();
            params->keys_object = temp.Pass();
          }
          params->keys_type = KEYS_OBJECT;
          break;
        }
        case Value::TYPE_LIST: {
          {
            ListValue* list = NULL;
            if (!keys_value->GetAsList(&list))
              return scoped_ptr<Params>();
            if (!json_schema_compiler::util::PopulateOptionalArrayFromList(*list, &params->keys_array))
              return scoped_ptr<Params>();
          }
          params->keys_type = KEYS_ARRAY;
          break;
        }
        default:
          return scoped_ptr<Params>();
      }
    }
  }

  return params.Pass();
}


StorageArea::Get::Result::Items::Items()
   {}
StorageArea::Get::Result::Items::~Items() {}

scoped_ptr<DictionaryValue> StorageArea::Get::Result::Items::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  value->MergeDictionary(&additional_properties);

  return value.Pass();
}


Value* StorageArea::Get::Result::Create(const Items& items) {
  return items.ToValue().release();
}


StorageChange::StorageChange()
   {}
StorageChange::~StorageChange() {}

// static
bool StorageChange::Populate(const Value& value, StorageChange* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* new_value_value = NULL;
  if (dict->GetWithoutPathExpansion("newValue", &new_value_value)) {
    {
      out->new_value.reset(new Any());
      out->new_value->Init(*new_value_value);
    }
  }

  Value* old_value_value = NULL;
  if (dict->GetWithoutPathExpansion("oldValue", &old_value_value)) {
    {
      out->old_value.reset(new Any());
      out->old_value->Init(*old_value_value);
    }
  }

  return true;
}

scoped_ptr<DictionaryValue> StorageChange::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  if (new_value.get())
    value->SetWithoutPathExpansion("newValue", this->new_value->value().DeepCopy());

  if (old_value.get())
    value->SetWithoutPathExpansion("oldValue", this->old_value->value().DeepCopy());


  return value.Pass();
}


}  // storage
}  // api
}  // extensions
