// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/storage.json
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_STORAGE_H__
#define CHROME_COMMON_EXTENSIONS_API_STORAGE_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace storage {
struct StorageChange;
}  // storage

namespace storage {

//
// Properties
//

// Items under the "local" namespace are local to each machine.
namespace local {
  // The maximum amount (in bytes) of data that can be stored in local storage.
  // This value will be ignored if the extension has the
  // <code>unlimitedStorage</code> permission. Updates that would cause this
  // limit to be exceeded fail.
  extern const int QUOTA_BYTES;
}  // namespace local

// Items under the "sync" namespace are synced using Chrome Sync.
namespace sync {
  // The maximum number of items that can be stored in sync storage. Updates that
  // would cause this limit to be exceeded will fail
  extern const int MAX_ITEMS;
  // The maximum size (in bytes) of each individual item in sync storage. Updates
  // containing items larger than this limit will fail.
  extern const int QUOTA_BYTES_PER_ITEM;
  // The maximum number of <code>set</code>, <code>remove</code>, or
  // <code>clear</code> operations that can be performed each hour. Updates that
  // would cause this limit to be exceeded fail.
  extern const int MAX_WRITE_OPERATIONS_PER_HOUR;
  // The maximum number of <code>set</code>, <code>remove</code>, or
  // <code>clear</code> operations that can be performed each minute, sustained
  // over 10 minutes. Updates that would cause this limit to be exceeded fail.
  extern const int MAX_SUSTAINED_WRITE_OPERATIONS_PER_MINUTE;
  // The maximum total amount (in bytes) of data that can be stored in sync
  // storage. Updates that would cause this limit to be exceeded fail immediately
  // and set chrome.extension.lastError.
  extern const int QUOTA_BYTES;
}  // namespace sync

//
// Types
//

namespace StorageArea {
  namespace GetBytesInUse {
    struct Params {
      enum KeysType {
        KEYS_NONE,
        KEYS_STRING,
        KEYS_ARRAY,
      };


      KeysType keys_type;

      scoped_ptr<std::string> keys_string;

      scoped_ptr<std::vector<std::string> > keys_array;

      ~Params();

      static scoped_ptr<Params> Create(const ListValue& args);

     private:
      Params();

      DISALLOW_COPY_AND_ASSIGN(Params);
    };

    namespace Result {
      // Amount of space being used in storage, in bytes.
      Value* Create(const int bytes_in_use);
    };

  };

  namespace Clear {

    namespace Result {
      Value* Create();
    };

  };

  namespace Set {
    struct Params {
      // Object specifying items to augment storage with. Values that cannot be
      // serialized (functions, etc) will be ignored.
      struct Items {
        ~Items();
        Items();

        base::DictionaryValue additional_properties;

        // Populates a Items object from a Value. Returns whether |out| was
        // successfully populated.
        static bool Populate(const Value& value, Items* out);


       private:
        DISALLOW_COPY_AND_ASSIGN(Items);
      };

      // Object specifying items to augment storage with. Values that cannot be
      // serialized (functions, etc) will be ignored.
      Items items;

      ~Params();

      static scoped_ptr<Params> Create(const ListValue& args);

     private:
      Params();

      DISALLOW_COPY_AND_ASSIGN(Params);
    };

    namespace Result {
      Value* Create();
    };

  };

  namespace Remove {
    struct Params {
      enum KeysType {
        KEYS_STRING,
        KEYS_ARRAY,
      };


      KeysType keys_type;

      scoped_ptr<std::string> keys_string;

      scoped_ptr<std::vector<std::string> > keys_array;

      ~Params();

      static scoped_ptr<Params> Create(const ListValue& args);

     private:
      Params();

      DISALLOW_COPY_AND_ASSIGN(Params);
    };

    namespace Result {
      Value* Create();
    };

  };

  namespace Get {
    struct Params {
      enum KeysType {
        KEYS_NONE,
        KEYS_STRING,
        KEYS_OBJECT,
        KEYS_ARRAY,
      };

      // Storage items to return in the callback, where the values are replaced with
      // those from storage if they exist.
      struct Keys {
        ~Keys();
        Keys();

        base::DictionaryValue additional_properties;

        // Populates a Keys object from a Value. Returns whether |out| was
        // successfully populated.
        static bool Populate(const Value& value, Keys* out);


       private:
        DISALLOW_COPY_AND_ASSIGN(Keys);
      };


      KeysType keys_type;

      scoped_ptr<std::string> keys_string;

      // Storage items to return in the callback, where the values are replaced with
      // those from storage if they exist.
      scoped_ptr<Keys> keys_object;

      scoped_ptr<std::vector<std::string> > keys_array;

      ~Params();

      static scoped_ptr<Params> Create(const ListValue& args);

     private:
      Params();

      DISALLOW_COPY_AND_ASSIGN(Params);
    };

    namespace Result {
      // Object with items in their key-value mappings.
      struct Items {
        ~Items();
        Items();

        base::DictionaryValue additional_properties;

        // Returns a new DictionaryValue representing the serialized form of this
        // Items object. Passes ownership to caller.
        scoped_ptr<DictionaryValue> ToValue() const;

       private:
        DISALLOW_COPY_AND_ASSIGN(Items);
      };

      // Object with items in their key-value mappings.
      Value* Create(const Items& items);
    };

  };

}

struct StorageChange {
  ~StorageChange();
  StorageChange();

  // The new value of the item, if there is a new value.
  scoped_ptr<json_schema_compiler::any::Any> new_value;

  // The old value of the item, if there was an old value.
  scoped_ptr<json_schema_compiler::any::Any> old_value;

  // Populates a StorageChange object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, StorageChange* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // StorageChange object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(StorageChange);
};

}  // storage
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_STORAGE_H__
