// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/web_navigation.json
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_WEB_NAVIGATION_H__
#define CHROME_COMMON_EXTENSIONS_API_WEB_NAVIGATION_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace web_navigation {
}  // web_navigation

namespace web_navigation {

//
// Functions
//

namespace GetFrame {
  struct Params {
    // Information about the frame to retrieve information about.
    struct Details {
      ~Details();
      Details();

      // The ID of the tab in which the frame is.
      int tab_id;

      // The ID of the frame in the given tab.
      int frame_id;

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    // Information about the frame to retrieve information about.
    Details details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    // Information about the requested frame, null if the specified frame ID and/or
    // tab ID are invalid.
    struct Details {
      ~Details();
      Details();

      // The URL currently associated with this frame, if the frame identified by the
      // frameId existed at one point in the given tab. The fact that an URL is
      // associated with a given frameId does not imply that the corresponding frame
      // still exists.
      std::string url;

      // True if the last navigation in this frame was interrupted by an error, i.e.
      // the onErrorOccurred event fired.
      bool error_occurred;

      // Returns a new DictionaryValue representing the serialized form of this
      // Details object. Passes ownership to caller.
      scoped_ptr<DictionaryValue> ToValue() const;

     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    // Information about the requested frame, null if the specified frame ID
    // and/or tab ID are invalid.
    Value* Create(const Details& details);
  };

};

namespace GetAllFrames {
  struct Params {
    // Information about the tab to retrieve all frames from.
    struct Details {
      ~Details();
      Details();

      // The ID of the tab.
      int tab_id;

      // Populates a Details object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, Details* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(Details);
    };

    // Information about the tab to retrieve all frames from.
    Details details;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    struct DetailsElement {
      ~DetailsElement();
      DetailsElement();

      // The URL currently associated with this frame, if the frame identified by the
      // frameId existed at one point in the given tab. The fact that an URL is
      // associated with a given frameId does not imply that the corresponding frame
      // still exists.
      std::string url;

      // True if the last navigation in this frame was interrupted by an error, i.e.
      // the onErrorOccurred event fired.
      bool error_occurred;

      // The ID of the frame. 0 indicates that this is the main frame; a positive
      // value indicates the ID of a subframe.
      int frame_id;

      // Returns a new DictionaryValue representing the serialized form of this
      // DetailsElement object. Passes ownership to caller.
      scoped_ptr<DictionaryValue> ToValue() const;

     private:
      DISALLOW_COPY_AND_ASSIGN(DetailsElement);
    };


    // A list of frames in the given tab, null if the specified tab ID is
    // invalid.
    Value* Create(const std::vector<linked_ptr<DetailsElement> >& details);
  };

};

}  // web_navigation
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_WEB_NAVIGATION_H__
