// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/windows.json
// DO NOT EDIT.

#include "tools/json_schema_compiler/util.h"
#include "chrome/common/extensions/api/windows.h"
#include "chrome/common/extensions/api/tabs.h"


using base::Value;
using base::DictionaryValue;
using base::ListValue;
using base::BinaryValue;
using json_schema_compiler::any::Any;

namespace extensions {
namespace api {
namespace windows {

//
// Properties
//

const int WINDOW_ID_NONE = -1;

const int WINDOW_ID_CURRENT = -2;

//
// Types
//

// static
scoped_ptr<Value> Window::CreateEnumValue(State state) {
  switch (state) {
    case STATE_NORMAL: {
      return scoped_ptr<Value>(Value::CreateStringValue("normal"));
    }
    case STATE_MINIMIZED: {
      return scoped_ptr<Value>(Value::CreateStringValue("minimized"));
    }
    case STATE_MAXIMIZED: {
      return scoped_ptr<Value>(Value::CreateStringValue("maximized"));
    }
    case STATE_FULLSCREEN: {
      return scoped_ptr<Value>(Value::CreateStringValue("fullscreen"));
    }
    default: {
      return scoped_ptr<Value>();
    }
  }
}

// static
scoped_ptr<Value> Window::CreateEnumValue(Type type) {
  switch (type) {
    case TYPE_NORMAL: {
      return scoped_ptr<Value>(Value::CreateStringValue("normal"));
    }
    case TYPE_POPUP: {
      return scoped_ptr<Value>(Value::CreateStringValue("popup"));
    }
    case TYPE_PANEL: {
      return scoped_ptr<Value>(Value::CreateStringValue("panel"));
    }
    case TYPE_APP: {
      return scoped_ptr<Value>(Value::CreateStringValue("app"));
    }
    default: {
      return scoped_ptr<Value>();
    }
  }
}

Window::Window()
  : top(0), height(0), width(0), focused(false), always_on_top(false), left(0), id(0), incognito(false) {}
Window::~Window() {}

// static
bool Window::Populate(const Value& value, Window* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* tabs_value = NULL;
  if (dict->GetWithoutPathExpansion("tabs", &tabs_value)) {
    {
      ListValue* list = NULL;
      if (!tabs_value->GetAsList(&list))
        return false;
      if (!json_schema_compiler::util::PopulateOptionalArrayFromList(*list, &out->tabs))
        return false;
    }
  }

  Value* top_value = NULL;
  if (!dict->GetWithoutPathExpansion("top", &top_value))
    return false;
  {
    if (!top_value->GetAsInteger(&out->top))
      return false;
  }

  Value* height_value = NULL;
  if (!dict->GetWithoutPathExpansion("height", &height_value))
    return false;
  {
    if (!height_value->GetAsInteger(&out->height))
      return false;
  }

  Value* width_value = NULL;
  if (!dict->GetWithoutPathExpansion("width", &width_value))
    return false;
  {
    if (!width_value->GetAsInteger(&out->width))
      return false;
  }

  Value* state_value = NULL;
  if (!dict->GetWithoutPathExpansion("state", &state_value))
    return false;
  {
    {
      State enum_temp;
      std::string enum_as_string;
      if (!state_value->GetAsString(&enum_as_string))
        return false;
      if(enum_as_string == "normal")
        enum_temp = STATE_NORMAL;
      else if(enum_as_string == "minimized")
        enum_temp = STATE_MINIMIZED;
      else if(enum_as_string == "maximized")
        enum_temp = STATE_MAXIMIZED;
      else if(enum_as_string == "fullscreen")
        enum_temp = STATE_FULLSCREEN;
      else
        return false;
      out->state = enum_temp;
    }
  }

  Value* focused_value = NULL;
  if (!dict->GetWithoutPathExpansion("focused", &focused_value))
    return false;
  {
    if (!focused_value->GetAsBoolean(&out->focused))
      return false;
  }

  Value* always_on_top_value = NULL;
  if (!dict->GetWithoutPathExpansion("alwaysOnTop", &always_on_top_value))
    return false;
  {
    if (!always_on_top_value->GetAsBoolean(&out->always_on_top))
      return false;
  }

  Value* left_value = NULL;
  if (!dict->GetWithoutPathExpansion("left", &left_value))
    return false;
  {
    if (!left_value->GetAsInteger(&out->left))
      return false;
  }

  Value* type_value = NULL;
  if (!dict->GetWithoutPathExpansion("type", &type_value))
    return false;
  {
    {
      Type enum_temp;
      std::string enum_as_string;
      if (!type_value->GetAsString(&enum_as_string))
        return false;
      if(enum_as_string == "normal")
        enum_temp = TYPE_NORMAL;
      else if(enum_as_string == "popup")
        enum_temp = TYPE_POPUP;
      else if(enum_as_string == "panel")
        enum_temp = TYPE_PANEL;
      else if(enum_as_string == "app")
        enum_temp = TYPE_APP;
      else
        return false;
      out->type = enum_temp;
    }
  }

  Value* id_value = NULL;
  if (!dict->GetWithoutPathExpansion("id", &id_value))
    return false;
  {
    if (!id_value->GetAsInteger(&out->id))
      return false;
  }

  Value* incognito_value = NULL;
  if (!dict->GetWithoutPathExpansion("incognito", &incognito_value))
    return false;
  {
    if (!incognito_value->GetAsBoolean(&out->incognito))
      return false;
  }

  return true;
}

scoped_ptr<DictionaryValue> Window::ToValue() const {
  scoped_ptr<DictionaryValue> value(new DictionaryValue());

  if (tabs.get())
    value->SetWithoutPathExpansion("tabs", json_schema_compiler::util::CreateValueFromOptionalArray(this->tabs).release());

  value->SetWithoutPathExpansion("top", Value::CreateIntegerValue(this->top));
  value->SetWithoutPathExpansion("height", Value::CreateIntegerValue(this->height));
  value->SetWithoutPathExpansion("width", Value::CreateIntegerValue(this->width));
  value->SetWithoutPathExpansion("state", CreateEnumValue(this->state).release());
  value->SetWithoutPathExpansion("focused", Value::CreateBooleanValue(this->focused));
  value->SetWithoutPathExpansion("alwaysOnTop", Value::CreateBooleanValue(this->always_on_top));
  value->SetWithoutPathExpansion("left", Value::CreateIntegerValue(this->left));
  value->SetWithoutPathExpansion("type", CreateEnumValue(this->type).release());
  value->SetWithoutPathExpansion("id", Value::CreateIntegerValue(this->id));
  value->SetWithoutPathExpansion("incognito", Value::CreateBooleanValue(this->incognito));

  return value.Pass();
}


//
// Functions
//

Get::Params::GetInfo::GetInfo()
   {}
Get::Params::GetInfo::~GetInfo() {}

// static
bool Get::Params::GetInfo::Populate(const Value& value, GetInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* populate_value = NULL;
  if (dict->GetWithoutPathExpansion("populate", &populate_value)) {
    {
      bool temp;
      if (!populate_value->GetAsBoolean(&temp))
        return false;
      out->populate.reset(new bool(temp));
    }
  }

  return true;
}


Get::Params::Params() {}
Get::Params::~Params() {}

// static
scoped_ptr<Get::Params> Get::Params::Create(const ListValue& args) {
  if (args.GetSize() < 1 || args.GetSize() > 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* window_id_value = NULL;
  if (args.Get(0, &window_id_value) && !window_id_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!window_id_value->GetAsInteger(&params->window_id))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* get_info_value = NULL;
  if (args.Get(1, &get_info_value) && !get_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!get_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      scoped_ptr<GetInfo> temp(new GetInfo());
      if (!GetInfo::Populate(*dictionary, temp.get()))
        return scoped_ptr<Params>();
      params->get_info = temp.Pass();
    }
  }

  return params.Pass();
}


Value* Get::Result::Create(const Window& window) {
  return window.ToValue().release();
}

GetCurrent::Params::GetInfo::GetInfo()
   {}
GetCurrent::Params::GetInfo::~GetInfo() {}

// static
bool GetCurrent::Params::GetInfo::Populate(const Value& value, GetInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* populate_value = NULL;
  if (dict->GetWithoutPathExpansion("populate", &populate_value)) {
    {
      bool temp;
      if (!populate_value->GetAsBoolean(&temp))
        return false;
      out->populate.reset(new bool(temp));
    }
  }

  return true;
}


GetCurrent::Params::Params() {}
GetCurrent::Params::~Params() {}

// static
scoped_ptr<GetCurrent::Params> GetCurrent::Params::Create(const ListValue& args) {
  if (args.GetSize() > 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* get_info_value = NULL;
  if (args.Get(0, &get_info_value) && !get_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!get_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      scoped_ptr<GetInfo> temp(new GetInfo());
      if (!GetInfo::Populate(*dictionary, temp.get()))
        return scoped_ptr<Params>();
      params->get_info = temp.Pass();
    }
  }

  return params.Pass();
}


Value* GetCurrent::Result::Create(const Window& window) {
  return window.ToValue().release();
}

// static
scoped_ptr<Value> Create::Params::CreateData::CreateEnumValue(Type type) {
  switch (type) {
    case TYPE_NONE: {
      return scoped_ptr<Value>();
    }
    case TYPE_NORMAL: {
      return scoped_ptr<Value>(Value::CreateStringValue("normal"));
    }
    case TYPE_POPUP: {
      return scoped_ptr<Value>(Value::CreateStringValue("popup"));
    }
    case TYPE_PANEL: {
      return scoped_ptr<Value>(Value::CreateStringValue("panel"));
    }
    default: {
      return scoped_ptr<Value>();
    }
  }
}

Create::Params::CreateData::CreateData()
   {}
Create::Params::CreateData::~CreateData() {}

// static
bool Create::Params::CreateData::Populate(const Value& value, CreateData* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  out->type = TYPE_NONE;
  Value* tab_id_value = NULL;
  if (dict->GetWithoutPathExpansion("tabId", &tab_id_value)) {
    {
      int temp;
      if (!tab_id_value->GetAsInteger(&temp))
        return false;
      out->tab_id.reset(new int(temp));
    }
  }

  Value* url_value = NULL;
  if (dict->GetWithoutPathExpansion("url", &url_value)) {
    {
      std::string temp;
      if (!url_value->GetAsString(&temp))
        return false;
      out->url.reset(new std::string(temp));
    }
  }

  Value* top_value = NULL;
  if (dict->GetWithoutPathExpansion("top", &top_value)) {
    {
      int temp;
      if (!top_value->GetAsInteger(&temp))
        return false;
      out->top.reset(new int(temp));
    }
  }

  Value* height_value = NULL;
  if (dict->GetWithoutPathExpansion("height", &height_value)) {
    {
      int temp;
      if (!height_value->GetAsInteger(&temp))
        return false;
      out->height.reset(new int(temp));
    }
  }

  Value* width_value = NULL;
  if (dict->GetWithoutPathExpansion("width", &width_value)) {
    {
      int temp;
      if (!width_value->GetAsInteger(&temp))
        return false;
      out->width.reset(new int(temp));
    }
  }

  Value* focused_value = NULL;
  if (dict->GetWithoutPathExpansion("focused", &focused_value)) {
    {
      bool temp;
      if (!focused_value->GetAsBoolean(&temp))
        return false;
      out->focused.reset(new bool(temp));
    }
  }

  Value* left_value = NULL;
  if (dict->GetWithoutPathExpansion("left", &left_value)) {
    {
      int temp;
      if (!left_value->GetAsInteger(&temp))
        return false;
      out->left.reset(new int(temp));
    }
  }

  Value* type_value = NULL;
  if (dict->GetWithoutPathExpansion("type", &type_value)) {
    {
      {
        Type enum_temp;
        std::string enum_as_string;
        if (!type_value->GetAsString(&enum_as_string))
          return false;
        if(enum_as_string == "normal")
          enum_temp = TYPE_NORMAL;
        else if(enum_as_string == "popup")
          enum_temp = TYPE_POPUP;
        else if(enum_as_string == "panel")
          enum_temp = TYPE_PANEL;
        else
          return false;
        out->type = enum_temp;
      }
    }
  }

  Value* incognito_value = NULL;
  if (dict->GetWithoutPathExpansion("incognito", &incognito_value)) {
    {
      bool temp;
      if (!incognito_value->GetAsBoolean(&temp))
        return false;
      out->incognito.reset(new bool(temp));
    }
  }

  return true;
}


Create::Params::Params() {}
Create::Params::~Params() {}

// static
scoped_ptr<Create::Params> Create::Params::Create(const ListValue& args) {
  if (args.GetSize() > 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* create_data_value = NULL;
  if (args.Get(0, &create_data_value) && !create_data_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!create_data_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      scoped_ptr<CreateData> temp(new CreateData());
      if (!CreateData::Populate(*dictionary, temp.get()))
        return scoped_ptr<Params>();
      params->create_data = temp.Pass();
    }
  }

  return params.Pass();
}


Value* Create::Result::Create(const Window& window) {
  return window.ToValue().release();
}

GetAll::Params::GetInfo::GetInfo()
   {}
GetAll::Params::GetInfo::~GetInfo() {}

// static
bool GetAll::Params::GetInfo::Populate(const Value& value, GetInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* populate_value = NULL;
  if (dict->GetWithoutPathExpansion("populate", &populate_value)) {
    {
      bool temp;
      if (!populate_value->GetAsBoolean(&temp))
        return false;
      out->populate.reset(new bool(temp));
    }
  }

  return true;
}


GetAll::Params::Params() {}
GetAll::Params::~Params() {}

// static
scoped_ptr<GetAll::Params> GetAll::Params::Create(const ListValue& args) {
  if (args.GetSize() > 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* get_info_value = NULL;
  if (args.Get(0, &get_info_value) && !get_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!get_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      scoped_ptr<GetInfo> temp(new GetInfo());
      if (!GetInfo::Populate(*dictionary, temp.get()))
        return scoped_ptr<Params>();
      params->get_info = temp.Pass();
    }
  }

  return params.Pass();
}


Value* GetAll::Result::Create(const std::vector<linked_ptr<Window> >& windows) {
  return json_schema_compiler::util::CreateValueFromArray(windows).release();
}

// static
scoped_ptr<Value> Update::Params::UpdateInfo::CreateEnumValue(State state) {
  switch (state) {
    case STATE_NONE: {
      return scoped_ptr<Value>();
    }
    case STATE_NORMAL: {
      return scoped_ptr<Value>(Value::CreateStringValue("normal"));
    }
    case STATE_MINIMIZED: {
      return scoped_ptr<Value>(Value::CreateStringValue("minimized"));
    }
    case STATE_MAXIMIZED: {
      return scoped_ptr<Value>(Value::CreateStringValue("maximized"));
    }
    case STATE_FULLSCREEN: {
      return scoped_ptr<Value>(Value::CreateStringValue("fullscreen"));
    }
    default: {
      return scoped_ptr<Value>();
    }
  }
}

Update::Params::UpdateInfo::UpdateInfo()
   {}
Update::Params::UpdateInfo::~UpdateInfo() {}

// static
bool Update::Params::UpdateInfo::Populate(const Value& value, UpdateInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  out->state = STATE_NONE;
  Value* top_value = NULL;
  if (dict->GetWithoutPathExpansion("top", &top_value)) {
    {
      int temp;
      if (!top_value->GetAsInteger(&temp))
        return false;
      out->top.reset(new int(temp));
    }
  }

  Value* draw_attention_value = NULL;
  if (dict->GetWithoutPathExpansion("drawAttention", &draw_attention_value)) {
    {
      bool temp;
      if (!draw_attention_value->GetAsBoolean(&temp))
        return false;
      out->draw_attention.reset(new bool(temp));
    }
  }

  Value* height_value = NULL;
  if (dict->GetWithoutPathExpansion("height", &height_value)) {
    {
      int temp;
      if (!height_value->GetAsInteger(&temp))
        return false;
      out->height.reset(new int(temp));
    }
  }

  Value* width_value = NULL;
  if (dict->GetWithoutPathExpansion("width", &width_value)) {
    {
      int temp;
      if (!width_value->GetAsInteger(&temp))
        return false;
      out->width.reset(new int(temp));
    }
  }

  Value* state_value = NULL;
  if (dict->GetWithoutPathExpansion("state", &state_value)) {
    {
      {
        State enum_temp;
        std::string enum_as_string;
        if (!state_value->GetAsString(&enum_as_string))
          return false;
        if(enum_as_string == "normal")
          enum_temp = STATE_NORMAL;
        else if(enum_as_string == "minimized")
          enum_temp = STATE_MINIMIZED;
        else if(enum_as_string == "maximized")
          enum_temp = STATE_MAXIMIZED;
        else if(enum_as_string == "fullscreen")
          enum_temp = STATE_FULLSCREEN;
        else
          return false;
        out->state = enum_temp;
      }
    }
  }

  Value* focused_value = NULL;
  if (dict->GetWithoutPathExpansion("focused", &focused_value)) {
    {
      bool temp;
      if (!focused_value->GetAsBoolean(&temp))
        return false;
      out->focused.reset(new bool(temp));
    }
  }

  Value* left_value = NULL;
  if (dict->GetWithoutPathExpansion("left", &left_value)) {
    {
      int temp;
      if (!left_value->GetAsInteger(&temp))
        return false;
      out->left.reset(new int(temp));
    }
  }

  return true;
}


Update::Params::Params() {}
Update::Params::~Params() {}

// static
scoped_ptr<Update::Params> Update::Params::Create(const ListValue& args) {
  if (args.GetSize() != 2)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* window_id_value = NULL;
  if (args.Get(0, &window_id_value) && !window_id_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!window_id_value->GetAsInteger(&params->window_id))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  Value* update_info_value = NULL;
  if (args.Get(1, &update_info_value) && !update_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!update_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      if (!UpdateInfo::Populate(*dictionary, &params->update_info))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Update::Result::Create(const Window& window) {
  return window.ToValue().release();
}

Remove::Params::Params() {}
Remove::Params::~Params() {}

// static
scoped_ptr<Remove::Params> Remove::Params::Create(const ListValue& args) {
  if (args.GetSize() != 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* window_id_value = NULL;
  if (args.Get(0, &window_id_value) && !window_id_value->IsType(Value::TYPE_NULL))
  {
    {
      if (!window_id_value->GetAsInteger(&params->window_id))
        return scoped_ptr<Params>();
    }
  }
  else {
    return scoped_ptr<Params>();
  }

  return params.Pass();
}


Value* Remove::Result::Create() {
  return Value::CreateNullValue();
}

GetLastFocused::Params::GetInfo::GetInfo()
   {}
GetLastFocused::Params::GetInfo::~GetInfo() {}

// static
bool GetLastFocused::Params::GetInfo::Populate(const Value& value, GetInfo* out) {
  if (!value.IsType(Value::TYPE_DICTIONARY))
    return false;
  const DictionaryValue* dict = static_cast<const DictionaryValue*>(&value);

  Value* populate_value = NULL;
  if (dict->GetWithoutPathExpansion("populate", &populate_value)) {
    {
      bool temp;
      if (!populate_value->GetAsBoolean(&temp))
        return false;
      out->populate.reset(new bool(temp));
    }
  }

  return true;
}


GetLastFocused::Params::Params() {}
GetLastFocused::Params::~Params() {}

// static
scoped_ptr<GetLastFocused::Params> GetLastFocused::Params::Create(const ListValue& args) {
  if (args.GetSize() > 1)
    return scoped_ptr<Params>();
  scoped_ptr<Params> params(new Params());

  Value* get_info_value = NULL;
  if (args.Get(0, &get_info_value) && !get_info_value->IsType(Value::TYPE_NULL))
  {
    {
      DictionaryValue* dictionary = NULL;
      if (!get_info_value->GetAsDictionary(&dictionary))
        return scoped_ptr<Params>();
      scoped_ptr<GetInfo> temp(new GetInfo());
      if (!GetInfo::Populate(*dictionary, temp.get()))
        return scoped_ptr<Params>();
      params->get_info = temp.Pass();
    }
  }

  return params.Pass();
}


Value* GetLastFocused::Result::Create(const Window& window) {
  return window.ToValue().release();
}

}  // windows
}  // api
}  // extensions
