// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// GENERATED FROM THE API DEFINITION IN
//   chrome/common/extensions/api/windows.json
// DO NOT EDIT.

#ifndef CHROME_COMMON_EXTENSIONS_API_WINDOWS_H__
#define CHROME_COMMON_EXTENSIONS_API_WINDOWS_H__
#pragma once

#include <string>
#include <vector>

#include "base/basictypes.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
#include "base/values.h"
#include "tools/json_schema_compiler/any.h"

namespace extensions {
namespace api {

namespace tabs {
struct Tab;
}
namespace windows {
struct Window;
}  // windows

namespace windows {

//
// Properties
//

// The windowId value that represents the absence of a chrome browser window.
extern const int WINDOW_ID_NONE;

// The windowId value that represents the <a
// href='windows.html#current-window'>current window</a>.
extern const int WINDOW_ID_CURRENT;

//
// Types
//

struct Window {
  ~Window();
  Window();


  enum State {
    STATE_NORMAL,
    STATE_MINIMIZED,
    STATE_MAXIMIZED,
    STATE_FULLSCREEN,
  };

  static scoped_ptr<Value> CreateEnumValue(State state);
  enum Type {
    TYPE_NORMAL,
    TYPE_POPUP,
    TYPE_PANEL,
    TYPE_APP,
  };

  static scoped_ptr<Value> CreateEnumValue(Type type);
  // Array of $ref:tabs.Tab objects representing the current tabs in the window.
  scoped_ptr<std::vector<linked_ptr<tabs::Tab> > > tabs;

  // The offset of the window from the top edge of the screen in pixels.
  int top;

  // The height of the window in pixels.
  int height;

  // The width of the window in pixels.
  int width;

  // The state of this browser window.
  State state;

  // Whether the window is currently the focused window.
  bool focused;

  // Whether the window is set to be always on top.
  bool always_on_top;

  // The offset of the window from the left edge of the screen in pixels.
  int left;

  // The type of browser window this is.
  Type type;

  // The ID of the window. Window IDs are unique within a browser session.
  int id;

  // Whether the window is incognito.
  bool incognito;

  // Populates a Window object from a Value. Returns whether |out| was
  // successfully populated.
  static bool Populate(const Value& value, Window* out);

  // Returns a new DictionaryValue representing the serialized form of this
  // Window object. Passes ownership to caller.
  scoped_ptr<DictionaryValue> ToValue() const;

 private:
  DISALLOW_COPY_AND_ASSIGN(Window);
};

//
// Functions
//

namespace Get {
  struct Params {
    struct GetInfo {
      ~GetInfo();
      GetInfo();

      // If true, the window object will have a <var>tabs</var> property that
      // contains a list of the $ref:tabs.Tab objects
      scoped_ptr<bool> populate;

      // Populates a GetInfo object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, GetInfo* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(GetInfo);
    };

    int window_id;

    scoped_ptr<GetInfo> get_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const Window& window);
  };

};

namespace GetCurrent {
  struct Params {
    struct GetInfo {
      ~GetInfo();
      GetInfo();

      // If true, the window object will have a <var>tabs</var> property that
      // contains a list of the $ref:tabs.Tab objects
      scoped_ptr<bool> populate;

      // Populates a GetInfo object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, GetInfo* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(GetInfo);
    };

    scoped_ptr<GetInfo> get_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const Window& window);
  };

};

namespace Create {
  struct Params {
    struct CreateData {
      ~CreateData();
      CreateData();

      enum Type {
        TYPE_NONE,
        TYPE_NORMAL,
        TYPE_POPUP,
        TYPE_PANEL,
      };

      static scoped_ptr<Value> CreateEnumValue(Type type);
      // The id of the tab for which you want to adopt to the new window.
      scoped_ptr<int> tab_id;

      // A URL or list of URLs to open as tabs in the window. Fully-qualified URLs
      // must include a scheme (i.e. 'http://www.google.com', not 'www.google.com').
      // Relative URLs will be relative to the current page within the extension.
      // Defaults to the New Tab Page.
      scoped_ptr<std::string> url;

      // The number of pixels to position the new window from the top edge of the
      // screen. If not specified, the new window is offset naturally from the last
      // focused window. This value is ignored for panels.
      scoped_ptr<int> top;

      // The height in pixels of the new window. If not specified defaults to a
      // natural height.
      scoped_ptr<int> height;

      // The width in pixels of the new window. If not specified defaults to a
      // natural width.
      scoped_ptr<int> width;

      // If true, opens an active window. If false, opens an inactive window.
      scoped_ptr<bool> focused;

      // The number of pixels to position the new window from the left edge of the
      // screen. If not specified, the new window is offset naturally from the last
      // focused window. This value is ignored for panels.
      scoped_ptr<int> left;

      // Specifies what type of browser window to create. The 'panel' type creates a
      // popup unless the '--enable-panels' flag is set.
      Type type;

      // Whether the new window should be an incognito window.
      scoped_ptr<bool> incognito;

      // Populates a CreateData object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, CreateData* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(CreateData);
    };

    scoped_ptr<CreateData> create_data;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    // Contains details about the created window.
    Value* Create(const Window& window);
  };

};

namespace GetAll {
  struct Params {
    struct GetInfo {
      ~GetInfo();
      GetInfo();

      // If true, each window object will have a <var>tabs</var> property that
      // contains a list of the $ref:tabs.Tab objects for that window.
      scoped_ptr<bool> populate;

      // Populates a GetInfo object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, GetInfo* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(GetInfo);
    };

    scoped_ptr<GetInfo> get_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {

    Value* Create(const std::vector<linked_ptr<Window> >& windows);
  };

};

namespace Update {
  struct Params {
    struct UpdateInfo {
      ~UpdateInfo();
      UpdateInfo();

      enum State {
        STATE_NONE,
        STATE_NORMAL,
        STATE_MINIMIZED,
        STATE_MAXIMIZED,
        STATE_FULLSCREEN,
      };

      static scoped_ptr<Value> CreateEnumValue(State state);
      // The offset from the top edge of the screen to move the window to in pixels.
      // This value is ignored for panels.
      scoped_ptr<int> top;

      // If true, causes the window to be displayed in a manner that draws the user's
      // attention to the window, without changing the focused window. The effect
      // lasts until the user changes focus to the window. This option has no effect
      // if the window already has focus. Set to false to cancel a previous draw
      // attention request.
      scoped_ptr<bool> draw_attention;

      // The height to resize the window to in pixels. This value is ignored for
      // panels.
      scoped_ptr<int> height;

      // The width to resize the window to in pixels. This value is ignored for
      // panels.
      scoped_ptr<int> width;

      // The new state of the window. The 'minimized', 'maximized' and 'fullscreen'
      // states cannot be combined with 'left', 'top', 'width' or 'height'.
      State state;

      // If true, brings the window to the front. If false, brings the next window in
      // the z-order to the front.
      scoped_ptr<bool> focused;

      // The offset from the left edge of the screen to move the window to in pixels.
      // This value is ignored for panels.
      scoped_ptr<int> left;

      // Populates a UpdateInfo object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, UpdateInfo* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(UpdateInfo);
    };

    int window_id;

    UpdateInfo update_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const Window& window);
  };

};

namespace Remove {
  struct Params {
    int window_id;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create();
  };

};

namespace GetLastFocused {
  struct Params {
    struct GetInfo {
      ~GetInfo();
      GetInfo();

      // If true, the window object will have a <var>tabs</var> property that
      // contains a list of the $ref:tabs.Tab objects
      scoped_ptr<bool> populate;

      // Populates a GetInfo object from a Value. Returns whether |out| was
      // successfully populated.
      static bool Populate(const Value& value, GetInfo* out);


     private:
      DISALLOW_COPY_AND_ASSIGN(GetInfo);
    };

    scoped_ptr<GetInfo> get_info;

    ~Params();

    static scoped_ptr<Params> Create(const ListValue& args);

   private:
    Params();

    DISALLOW_COPY_AND_ASSIGN(Params);
  };

  namespace Result {
    Value* Create(const Window& window);
  };

};

}  // windows
}  // api
}  // extensions

#endif  // CHROME_COMMON_EXTENSIONS_API_WINDOWS_H__
